<?php



namespace WpieApp\Core\Admin;

use WpieApp\Core\Utils\DB;
use WpieApp\Core\Helpers\Helper;
use WpieApp\Modules\Schedules\Controller\Event;

defined( 'WPIE__FILE__' ) || exit;


class Installer {

        
        public static function init() {

                \register_activation_hook( WPIE__FILE__, [ __CLASS__, 'activation' ] );

                \register_deactivation_hook( WPIE__FILE__, [ __CLASS__, 'deactivation' ] );

                \add_action( 'wpmu_new_blog', [ __CLASS__, 'activateBlog' ] );
                \add_action( 'activate_blog', [ __CLASS__, 'activateBlog' ] );
                \add_filter( 'wpmu_drop_tables', [ __CLASS__, 'onDeleteBlog' ] );
        }

        
        public static function activation( $network_wide = false ) {

                if ( !is_multisite() || !$network_wide ) {
                        self::activate();
                        return;
                }

                self::networkActivateDeactivate();
        }

        
        public static function deactivation( $network_wide = false ) {

                if ( !is_multisite() || !$network_wide ) {
                        self::deactivate();
                        return;
                }

                self::network_activate_deactivate( false );
        }

        
        private static function networkActivateDeactivate( $activate = true ) {

                $blog_ids = DB::wpdb()->get_col( "SELECT blog_id FROM " . DB::wpdb()->blogs . " WHERE archived = '0' AND spam = '0' AND deleted = '0'" );

                if ( Helper::isEmpty( $blog_ids ) ) {
                        return;
                }

                foreach ( $blog_ids as $blog_id ) {
                        \switch_to_blog( $blog_id );
                        (true === $activate) ? self::activate() : self::deactivate();
                        \restore_current_blog();
                }
        }

        
        private static function activate() {

                self::install();

                
                \do_action( 'Wpie/Plugin/Activate' );
        }

        
        public static function install() {

                $current_version = Helper::getOption( 'version' );

                self::createDBTables();

                if ( !$current_version ) {

                        self::createUploadFiles();

                        // Update to latest version.
                        Helper::setOption( 'version', WPIE_VERSION );
                        Helper::setOption( 'db_version', WPIE_DB_VERSION );

                        // Save install date.
                        if ( !Helper::getOption( 'install_date' ) ) {
                                Helper::setOption( 'install_date', \current_time( 'timestamp' ) );
                        }
                }
        }

        
        private static function deactivate() {

                Event::deactivate();

                
                \do_action( 'Wpie/Plugin/Deactivate' );
        }

        
        private static function createDBTables() {

                $tableName = DB::getPluginTable();

                if ( $tableName === DB::wpdb()->get_var( DB::wpdb()->prepare( "SHOW TABLES LIKE %s", $tableName ) ) ) {
                        return;
                }

                $collate = DB::wpdb()->get_charset_collate();

                $tables = [
                        "CREATE TABLE IF NOT EXISTS {$tableName} (
				id BIGINT(20) UNSIGNED NOT NULL AUTO_INCREMENT,
                                uid VARCHAR(100) NOT NULL,
                                status VARCHAR(25),
                                content_type VARCHAR(100) NOT NULL,
                                category VARCHAR(100) NOT NULL,
                                process VARCHAR(100) NOT NULL,
                                process_type VARCHAR(100) NOT NULL,
                                options LONGTEXT,
                                log VARCHAR(255),
                                total BIGINT(20),
                                records_per_iteration BIGINT(20),
                                name VARCHAR(255),
                                filedir VARCHAR(255),
                                file VARCHAR(255),
                                user VARCHAR(100),
                                parent BIGINT(20),
                                is_locked INT(11),
                                created_date DATETIME NOT NULL,
                                updated_date DATETIME NOT NULL,
				PRIMARY KEY (id)
			) {$collate};"
                ];

                require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );

                foreach ( $tables as $table ) {
                        \dbDelta( $table );
                }

                unset( $collate, $tableName, $tables );
        }

        
        private static function createUploadFiles() {

                $files = [
                        [ 'file' => '.htaccess', 'content' => 'deny from all' ],
                        [ 'file' => 'index.html', 'content' => '' ]
                ];

                $dirs = [
                        WPIE_UPLOAD_DIR,
                        WPIE_UPLOAD_EXPORT_DIR,
                        WPIE_UPLOAD_IMPORT_DIR,
                        WPIE_UPLOAD_TEMP_DIR,
                        WPIE_UPLOAD_FILE_DIR,
                        WPIE_LOG_DIR
                ];

                foreach ( $dirs as $dir ) {

                        if ( !wp_mkdir_p( $dir ) ) {
                                continue;
                        }

                        foreach ( $files as $file ) {

                                $path = $dir . DIRECTORY_SEPARATOR . $file[ 'file' ];

                                if ( !file_exists( $path ) ) {
                                        Helper::getFilesystem()->put_contents( $path, $file[ 'content' ] );
                                }
                        }
                }

                unset( $files, $dirs );
        }

        
        public static function activateBlog( $blog_id ) {

                if ( 1 !== \did_action( 'wpmu_new_blog' ) ) {
                        return;
                }

                \switch_to_blog( $blog_id );
                self::activate();
                \restore_current_blog();
        }

        
        public static function onDeleteBlog( $tables = [] ) {

                $tables[] = DB::getPluginTable();

                return $tables;
        }
}
