<?php



namespace WpieApp\Core\Helpers;

defined( 'WPIE__FILE__' ) || exit;


trait WpPlugins {

        
        public static function isPluginActive( $name = "" ) {

                // Nothing to do if WordPress is in "installation" mode..
                if ( !Helper::isNonEmptyStr( $name ) ) {
                        return false;
                }

                $isActive = false;

                $name = Helper::sanitizeKey( $name );

                switch ( $name ) {
                        case "woocommerce":
                        case "wc":
                                $isActive = \defined( 'WC_VERSION' ) || \class_exists( '\WooCommerce' );
                                break;
                        case "yoastseo":
                                $isActive = \defined( "WPSEO_VERSION" );
                                break;
                        case "allinoneseo":
                                $isActive = \defined( "AIOSEO_VERSION" ) || function_exists( '\aioseo' );
                                break;
                        case "rankmathseo":
                                $isActive = \defined( "RANK_MATH_VERSION" ) || \class_exists( '\RankMath' );
                                break;
                        case "polylang":
                                $isActive = \defined( "POLYLANG_VERSION" ) || \defined( "POLYLANG_PRO" );
                                break;
                        case "wpml":
                                $isActive = class_exists( '\SitePress' );
                                break;
                        case "acf":
                                $isActive = class_exists( '\ACF' );
                                break;
                        case "php":
                                $isActive = true;
                                break;
                }

                return $isActive;
        }

        
        public static function hasRequiredPlugin( $name = "", $requiredVersion = '' ) {

                // Nothing to do if WordPress is in "installation" mode..
                if ( Helper::isEmptyStr( $name ) ) {
                        return false;
                }

                $version = '';

                $name = Helper::sanitizeKey( $name );

                switch ( $name ) {
                        case "woocommerce":
                        case "wc":
                                $version = \defined( 'WC_VERSION' ) ? WC_VERSION : '';
                                break;
                        case "yoastseo":
                                $version = \defined( "WPSEO_VERSION" ) ? WPSEO_VERSION : '';
                                break;
                        case "allinoneseo":
                                $version = \defined( "AIOSEO_VERSION" ) ? AIOSEO_VERSION : '';
                                break;
                        case "rankmathseo":
                                $version = \defined( "RANK_MATH_VERSION" ) ? RANK_MATH_VERSION : '';
                                break;
                        case "polylang":
                                $version = \defined( "POLYLANG_VERSION" ) ? POLYLANG_VERSION : '';
                                break;
                        case "wpml":
                                $version = \defined( "ICL_SITEPRESS_VERSION" ) ? ICL_SITEPRESS_VERSION : '';
                                break;
                        case "acf":
                                $version = \defined( "ACF_VERSION" ) ? ACF_VERSION : '';
                                break;
                        case "php":
                                $version = \phpversion();
                                break;
                }

                if ( Helper::isNonEmptyStr( $version ) && version_compare( $version, $requiredVersion, '>=' ) ) {
                        return true;
                }

                return false;
        }
}
