<?php

namespace WpieApp\Core\Office\Converter;

use WpieApp\Core\Helpers\Helper;
use WpieApp\Core\Resource\Resource;
use WpieApp\Core\Utils\OpenSpout;

defined( 'ABSPATH' ) || exit;

class Excel2 {

        
        public static function convert( $file = "", $format = "", $start = 0 ) {

                if ( !is_readable( $file ) ) {
                        return new \WP_Error( 'php_format_convert_error', __( 'File is not readable', 'wp-import-export' ) );
                }

                $format = Helper::isEmptyStr( $format ) ? "" : Helper::sanitizeKey( $format );

                if ( Helper::isEmptyStr( $format ) || !in_array( $format, [ "xlsx", "ods", "csv" ] ) ) {
                        return new \WP_Error( 'php_format_convert_error', __( 'Invalid Spreadsheet Format', 'wp-import-export' ) );
                }

                $dir = \pathinfo( $file, PATHINFO_DIRNAME );

                $filename = Helper::pathJoin( $dir, Helper::sanitizeFilename( \pathinfo( $file, PATHINFO_FILENAME ), $format ) );

                //init Reader
                $reader = OpenSpout::getReader( $file );

                //init Writer
                $writer = OpenSpout::getWriter( $filename );

                // let's read the entire spreadsheet...
                foreach ( $reader->getSheetIterator() as $sheetIndex => $sheet ) {
                        // Add sheets in the new file, as we read new sheets in the existing one
                        if ( $sheetIndex !== 1 ) {
                                continue;
                        }

                        $count = 0;

                        foreach ( $sheet->getRowIterator() as $row ) {

                                if ( Resource::isExceeded() ) {
                                        break;
                                }
                                $count++;

                                if ( $count < $start ) {
                                        continue;
                                }
                                $writer->addRow( $row );
                        }

                        break;
                }

                $reader->close();

                $writer->close();

                return true;
        }
}
