<?php

namespace WpieApp\Core\Office\Reader\XML;

use WpieApp\Core\Helpers\Helper;
use XMLReader;
use WP_Error;

defined( 'WPIE__FILE__' ) || exit;


class FileReader extends XMLReader {

        
        protected $root;

        
        protected $prevDepth = 0;

        
        protected $nodesParsed = [];

        
        protected $nodesCounter = [];

        
        protected $node;

        
        protected $count = 0;

        
        protected $file = "";

        
        protected $options = [];

        
        public function load( $file = "", $options = [] ) {

                if ( !class_exists( "\XMLReader" ) ) {
                        return new WP_Error( 'wpieError', __( 'XML Class XMLReader is Missing', 'wp-import-export' ) );
                }

                if ( !\file_exists( $file ) ) {
                         /* translators: %s: File path */
                        return new WP_Error( 'wpieError', sprintf( __( '%s XML File not exists', 'wp-import-export' ), $file ) );
                }

                if ( !$this->open( $file ) ) {
                         /* translators: %s: File path */
                        return new WP_Error( 'wpieError', sprintf( __( '%s Invalid XML File to read', 'wp-import-export' ), $file ) );
                }

                $this->setParserProperty( self::VALIDATE, false );

                $this->file = $file;

                $this->setOptions( $options );

                $this->count = 0;

                return true;
        }

        
        public function setOptions( $options = [] ) {

                $this->options = $options;

                $this->root = isset( $options[ 'root' ] ) ? $options[ 'root' ] : "";

                if ( !Helper::isNonEmptyStr( $this->root ) ) {
                        return;
                }

                $node = Helper::strToArr( $this->root, '/' );

                $this->node = end( $node );
        }

        
        public function nextData() {
                return $this->nextNode();
        }

        
        public function nextNode() {

                while ( $read = $this->canRead() ) {

                        if ( self::ELEMENT !== $this->nodeType ) {
                                continue;
                        }

                        if ( $this->node !== $this->localName ) {
                                continue;
                        }

                        $this->addPath();

                        if ( $this->root !== $this->getPath() ) {
                                continue;
                        }

                        $this->count++;

                        break;
                }


                return $read;
        }

        
        public function canRead() {

                $read = $this->read();

                $this->addPath();

                return $read;
        }

        
        public function addPath() {

                if ( $this->depth < $this->prevDepth ) {
                        $this->nodesParsed = array_slice( $this->nodesParsed, 0, $this->depth + 1, true );
                }

                if ( !isset( $this->nodesParsed[ $this->depth ] ) || $this->localName !== $this->nodesParsed[ $this->depth ] ) {

                        $this->nodesParsed[ $this->depth ] = $this->localName;
                }

                $this->prevDepth = $this->depth;
        }

        
        public function getPath() {

                return \implode( "/", $this->nodesParsed );
        }

        
        public function goToRow( $offset = 1 ) {

                $offset = Helper::toInt( $offset );

                if ( $this->count === $offset ) {
                        return;
                }

                if ( $this->count > $offset && $offset >= 1 ) {
                        $this->rewind();
                }

                while ( ( $this->count < $offset) && $this->nextNode() ) {
                        
                }
        }

        
        public function rewind() {

                $this->close();

                $this->load( $this->file, $this->options );
        }

        
        public function getNodeNumber() {

                return $this->count;
        }

        
        public function getRootNode() {

                return $this->node;
        }

        
        protected function reset() {

                $this->nodesCounter = [];
        }
}
