<?php



namespace WpieApp\Core\Office\Reader\XML;

use WpieApp\Core\Helpers\Helper;

defined( 'WPIE__FILE__' ) || exit;


class XmlArray extends FileReader {

	
	public function getNode( $offset = 0 ) {

		if ( $offset !== 0 ) {
			$this->setNode( $offset );
		}

		return [ "path" => $this->root, 'tag' => $this->node, 'attr' => $this->getAttributes(), 'val' => $this->getData( $this->root ) ];
	}

	
	public function setNode( $offset = 0 ) {

		$offset = Helper::toInt( $offset );

		if ( $offset > 0 ) {
			$this->goToRow( $offset );
		} else {
			$this->nextNode();
		}
	}

	
	private function getData( $nodePath = "" ) {

		$data = [];

		while ( $read = $this->canRead() ) {

			if ( self::END_ELEMENT === $this->nodeType && $nodePath === $this->getPath() ) {
				break;
			}

			if ( in_array( $this->nodeType, [ self::TEXT, self::CDATA ] ) ) {
				$data = $this->value;
				break;
			}
                        
                     

			if ( self::ELEMENT !== $this->nodeType ) {
				continue;
			}

			$tag = $this->localName;

			$attr = [];

			if ( $this->hasAttributes ) {
				$attr = $this->getAttributes();
			}
                 
			$nodeData = [ "path" => $this->getNodePath(), 'tag' => $tag, 'val' => $this->isEmptyElement ? "" : $this->getData( $this->getPath() ) ];

			if ( Helper::isNonEmptyArray( $attr ) ) {
				$nodeData[ 'attr' ] = $attr;
			}

			$data[] = $nodeData;
		}

		return $read ? $data : false;
	}

	
	public function getNodePath() {

		$path = parent::getPath();

		$this->nodesCounter[ $path ] = isset( $this->nodesCounter[ $path ] ) ? $this->nodesCounter[ $path ] + 1 : 1;

		$path = $this->nodesCounter[ $path ] > 1 ? $path . "[" . $this->nodesCounter[ $path ] . "]" : $path;

		return $path;
	}

	
	private function getAttributes() {

		if ( !$this->hasAttributes ) {
			return "";
		}

		$attributes = [];

		while ( $this->moveToNextAttribute() ) {

			if ( "xmlns" === $this->name ) {
				continue;
			}
			$attributes[ $this->name ] = $this->value;
		}

		return $attributes;
	}

}
