<?php

namespace WpieApp\Core\Office\Reader\XML;

use WpieApp\Core\Helpers\Helper;
use XMLReader;

defined( 'WPIE__FILE__' ) || exit;


class XmlNode extends FileReader {

        
        private $data = [];

        
        public function getNode( $offset = 0 ) {

                $this->setNode( $offset );

                return $this->current();
        }

        
        public function get() {

                $this->nextNode();

                return $this->current();
        }

        
        public function current() {

                $this->reset();

                $this->data = [];

                $path = $this->getNodePath();

                $this->processAttributes( $path );

                while ( $read = $this->canRead() ) {

                        if ( self::END_ELEMENT === $this->nodeType && $this->root === $this->getPath() ) {
                                break;
                        }

                        $this->processData( $path );

                        if ( self::ELEMENT !== $this->nodeType ) {
                                continue;
                        }

                        $path = $this->getNodePath();

                        $this->processAttributes( $path );
                }

                return $read === false && !Helper::isNonEmptyArray( $this->data ) ? false : $this->data;
        }

        
        private function setNode( $offset = 0 ) {

                $offset = Helper::toInt( $offset );

                if ( $offset > 0 ) {
                        $this->goToRow( $offset );
                } else {
                        $this->nextNode();
                }
        }

        
        public function getNodePath() {

                $path = parent::getPath();

                $this->nodesCounter[ $path ] = isset( $this->nodesCounter[ $path ] ) ? $this->nodesCounter[ $path ] + 1 : 1;

                $path = $this->nodesCounter[ $path ] > 1 ? $path . "[" . $this->nodesCounter[ $path ] . "]" : $path;

                $path = substr( $path, strlen( $this->root ) + 1 );

                return $path;
        }

        
        private function processData( $path = "" ) {

                if ( !in_array( $this->nodeType, [ self::TEXT, self::CDATA ] ) ) {
                        return;
                }

                if ( !Helper::isNonEmptyStr( $path ) ) {
                        $roots = explode( '/', $this->root );
                        $path  = end( $roots );
                }

                $this->data[ $path ] = $this->value;
        }

        
        private function processAttributes( $path = "" ) {

                if ( !$this->hasAttributes ) {
                        return;
                }

                while ( $this->moveToNextAttribute() ) {
                        $this->data[ $path . '/@' . $this->name ] = $this->value;
                }
        }
}
