<?php


namespace WpieApp\Core\Page\Blocks\Templates\Processbar;

use WpieApp\Core\Helpers\Helper;
use WpieApp\Core\Page\Blocks\Fields;
use WpieApp\Core\Page\Blocks\Fields\Alert;

defined( 'WPIE__FILE__' ) || exit;


class Manager {

        
        public static function render( $data = [] ) {

                $manageExportUrl    = Helper::adminUrl( 'wpie-logs' );
                $manageSchedulesUrl = Helper::adminUrl( 'wpie-schedules' );
                ?>
                <div class="wpie-section wpie-exporting-data mt-4 d-none">
                        <?php
                        Alert::addNotes( [
                                [
                                        "type"       => "primary",
                                        "icon-class" => "fa-solid fa-circle-info",
                                        "class"      => "mb-4 wpie-export-processing-alert me-3",
                                        "text"       => __( 'Please wait while the export is being processed', 'wp-import-export' )
                                ],
                                [
                                        "type"       => "success",
                                        "icon-class" => "fa-solid fa-circle-info",
                                        "class"      => "mb-4 wpie-export-completed-alert d-none me-3",
                                        "text"       => __( '<strong>Download Bundle</strong> : The bundle includes your exported data and a settings file. Upload the bundle to any site for a fast and hassle-free data import', 'wp-import-export' )
                                ]
                        ] );
                        ?>

                        <div class="row m-auto p-0 me-3 wpie-section-container bg-white border pb-4 mt-4">
                                <div class="mb-4 text-center border-bottom py-4">
                                        <h2 class="m-0 wpie-export-processing-header-label"><?php esc_html_e( 'Export', 'wp-import-export' ); ?></h2>
                                </div>
                                <div class="m-auto text-center bse-fs-14 text-success mx-2 wpie-export-processing-header-info bse-fw-500"></div>                    
                                <div class="mx-atuo text-center my-5 wpie-export-processing-btns">
                                        <button type="button" class="btn btn-success btn-lg wpie-resume-export-btn d-none me-4"><i class="fa-solid fa-play me-2"></i><?php esc_html_e( 'Resume', 'wp-import-export' ); ?></button>
                                        <button type="button" class="btn btn-primary btn-lg wpie-pause-export-btn me-4"><i class="fa-solid fa-pause me-2"></i><?php esc_html_e( 'Pause', 'wp-import-export' ); ?></button>
                                        <button type="button" class="btn btn-danger btn-lg wpie-stop-export-btn me-4"><i class="fa-solid fa-circle-stop me-2"></i><?php esc_html_e( 'Stop', 'wp-import-export' ); ?></button>
                                        <button type="button" class="btn btn-primary btn-lg wpie-bg-export-btn"><i class="fa-solid fa-arrows-spin me-2"></i><?php esc_html_e( 'Export In Background', 'wp-import-export' ); ?></button>
                                </div>

                                <div class="mx-atuo text-center my-5 wpie-export-schedule-btns d-none">				
                                        <a href="<?php echo esc_url( $manageSchedulesUrl ); ?>" class="shadow-none text-white btn btn-primary btn-lg wpie-manage-schedule-btn me-4"><i class="fa-solid fa-gears me-2"></i><?php esc_html_e( 'Manage Schedules', 'wp-import-export' ); ?></a>
                                        <a href="<?php echo esc_url( $manageExportUrl ); ?>" class="shadow-none text-white btn btn-primary btn-lg wpie-manage-import-btn me-4"><i class="fa-solid fa-gears me-2"></i><?php esc_html_e( 'Manage Exports', 'wp-import-export' ); ?></a>                                
                                        <button type="button" class="btn btn-success btn-lg wpie-new-export-btn"><i class="fa-solid fa-plus"></i><?php esc_html_e( 'New Export', 'wp-import-export' ); ?></button>
                                </div>
                                <div class="mx-atuo text-center my-5 wpie-export-completed-btns d-none">				
                                        <button type="button" class="btn btn-primary btn-lg wpie-download-file-btn me-4"><i class="fa-solid fa-download me-2"></i><?php esc_html_e( 'Download File', 'wp-import-export' ); ?></button>
                                        <button type="button" class="btn btn-success btn-lg wpie-download-bundle-btn me-4"><i class="fa-solid fa-gears me-2"></i><?php esc_html_e( 'Download Bundle', 'wp-import-export' ); ?></button>
                                        <a href="<?php echo esc_url( $manageExportUrl ); ?>" target="_blank" class="shadow-none text-white btn btn-secondary btn-lg wpie-manage-export-btn me-4"><i class="fa-solid fa-gears me-2"></i><?php esc_html_e( 'Manage Exports', 'wp-import-export' ); ?></a>
                                        <button type="button" class="btn btn-success btn-lg wpie-new-export-btn d-none"><i class="fa-solid fa-plus me-2"></i><?php esc_html_e( 'New Export', 'wp-import-export' ); ?></button>
                                </div>
                                <div class="row m-0 p-0 wpie-export-process-container">
                                        <div class="col-12 col-lg m-auto">
                                                <div class="wpie-circle wpie-circle-50-plus wpie-export-processbar">
                                                        <span class="wpie-circle-percentage wpie-export-process-percentage"></span>
                                                        <div class="wpie-slice">
                                                                <div class="wpie-bar"></div>
                                                                <div class="wpie-fill"></div>
                                                        </div>
                                                </div>
                                        </div>
                                        <div class="col-12 col-lg">
                                                <div class="mb-5 border-start border-2 px-3">
                                                        <div class="wpie-export-process-status bse-fs-24 bse-fw-500 bse-text-orange wpie-export-processing-info"><?php esc_html_e( 'Waiting', 'wp-import-export' ); ?></div>
                                                        <div class="bse-fs-14 bse-fw-500 text-secondary"><?php esc_html_e( 'Status', 'wp-import-export' ); ?></div>
                                                </div>
                                                <div class="mb-5 border-start border-2 px-3">
                                                        <div class="wpie-export-process-time bse-fs-24 bse-fw-500 bse-text-orange wpie-export-processing-info"></div>
                                                        <div class="bse-fs-14 bse-fw-500 text-secondary"><?php esc_html_e( 'Time', 'wp-import-export' ); ?></div>
                                                </div>
                                                <div class="mb-5 border-start border-2 px-3">
                                                        <div class="wpie-export-process-content-type bse-fs-24 bse-fw-500 bse-text-orange wpie-export-processing-info"></div>
                                                        <div class="bse-fs-14 bse-fw-500 text-secondary"><?php esc_html_e( 'Exporting Data', 'wp-import-export' ); ?></div>
                                                </div>
                                        </div>
                                        <div class="col-12 col-lg">
                                                <div class="mb-5 border-start border-2 px-3">
                                                        <div class="wpie-export-process-total bse-fs-24 bse-fw-500 bse-text-orange wpie-export-processing-info"></div>
                                                        <div class="bse-fs-14 bse-fw-500 text-secondary"><?php esc_html_e( 'Total', 'wp-import-export' ); ?></div>
                                                </div>
                                                <div class="mb-5 border-start border-2 px-3">
                                                        <div class="wpie-export-process-processed bse-fs-24 bse-fw-500 bse-text-orange wpie-export-processing-info"></div>
                                                        <div class="bse-fs-14 bse-fw-500 text-secondary"><?php esc_html_e( 'Processed', 'wp-import-export' ); ?></div>
                                                </div>

                                        </div>
                                        <div class="col-12 col-lg d-none wpie-export-process-filter-section">
                                                <div class="mb-5 border-start border-2 px-3">
                                                        <div class="wpie-export-process-created bse-fs-24 bse-fw-500 bse-text-orange wpie-export-processing-info"></div>
                                                        <div class="bse-fs-14 bse-fw-500 text-secondary"><?php esc_html_e( 'Total Available', 'wp-import-export' ); ?></div>
                                                </div>
                                                <div class="mb-5 border-start border-2 px-3">
                                                        <div class="wpie-export-process-updated bse-fs-24 bse-fw-500 bse-text-orange wpie-export-processing-info"></div>
                                                        <div class="bse-fs-14 bse-fw-500 text-secondary"><?php esc_html_e( 'Filtered', 'wp-import-export' ); ?></div>
                                                </div>

                                        </div>

                                </div>
                        </div>
                </div>
                <?php
        }
}
