<?php



namespace WpieApp\Core\Resource;

defined( 'WPIE__FILE__' ) || exit;


class Time {

        
        private static $isMaximumLimit = false;

        
        private static $timeLimit;

        
        private static $startTime;

        
        const MAX_LIMIT = 90;

        
        public static function isExceeded( $limit = 0 ) {

                $limit = \absint( $limit ) > 0 ? $limit : self::MAX_LIMIT;

                if ( self::getUsagePer() >= \absint( $limit ) ) {
                        return true;
                }

                return false;
        }

        
        public static function setStartTime() {
                if ( !self::$startTime ) {
                        self::$startTime = \microtime( true ) - 2;
                }
        }

        
        private static function getStartTime() {
                if ( !self::$startTime ) {
                        self::setStartTime();
                }

                return self::$startTime;
        }

        
        private static function getTimeLimit() {

                if ( self::$timeLimit ) {
                        return self::$timeLimit;
                }

                if ( function_exists( '\ini_get' ) ) {
                        $time = \ini_get( 'max_execution_time' );
                } else {
                        // Sensible default.
                        $time = 30;
                }

                if ( !$time || 0 === intval( $time ) ) {
                        $time = HOUR_IN_SECONDS;  //1 hour
                }

                self::$timeLimit = intval( $time );

                return self::$timeLimit;
        }

        
        public static function getTimeOut() {

                $timeTotal = self::getTimeLimit();

                $usage = \microtime( true ) - self::getStartTime();

                $usage = $usage < 1 ? 1 : $usage;

                return $timeTotal - $usage;
        }

        
        private static function getUsagePer() {

                $timeTotal = self::getTimeLimit();

                $usage = \microtime( true ) - self::getStartTime();

                $usage = $usage < 1 ? 1 : $usage;

                if ( $timeTotal < $usage ) {
                        return 100;
                }

                return ($usage * 100) / $timeTotal;
        }

        
        public static function increase() {

                if ( self::$isMaximumLimit ) {
                        return;
                }

                self::$isMaximumLimit = true;

                $max_execution_time = ( int ) \ini_get( 'max_execution_time' );

                /*
                 * If the max execution time is already unlimited (zero), or if it exceeds or is equal to the proposed
                 * limit, there is no reason for us to make further changes (we never want to lower it).
                 */
                if ( 0 === $max_execution_time ) {
                        return;
                }

                $maxLimit = 0;

                if ( function_exists( '\set_time_limit' ) && false === strpos( \ini_get( 'disable_functions' ), 'set_time_limit' ) && !\ini_get( 'safe_mode' ) ) { // phpcs:ignore PHPCompatibility.IniDirectives.RemovedIniDirectives.safe_modeDeprecatedRemoved
                        // phpcs:ignore WordPress.PHP.NoSilencedErrors.Discouraged                     
                        // phpcs:ignore Squiz.PHP.DiscouragedFunctions.Discouraged
                        if ( @\set_time_limit( $maxLimit ) ) {
                                self::$timeLimit = 1 * 60 * 60;
                        }
                }
        }
}
