<?php



namespace WpieApp\Extensions\Export\WooCommerce\Controller\Items\Order\Standard\Filters;

use WpieApp\Core\Utils\DB;
use WpieApp\Core\Helpers\Helper;
use WpieApp\Extensions\Export\WooCommerce\Controller\Items\Order\Standard\Filter;
use WpieApp\Modules\Export\Controller\Items\Base\Filters\Filter as BaseFilter;
use WpieApp\Extensions\Export\WooCommerce\Controller\Items\Order\Standard\Query\Order;

defined( 'WPIE__FILE__' ) || exit;


class ItemMeta extends BaseFilter {

        
        protected static $isJoinQueryAdded = false;

        
        protected static $tableAlias = "itemmeta";

        
        public static function addRule() {

                $element = Filter::getOption( "element", "field" );

                if ( !Helper::isNonEmptyStr( $element ) ) {
                        return false;
                }

                static::addJoinQuery();

                $condition = Filter::getOption( 'condition' );

                if ( in_array( $condition, [ "not_equals", "not_contains", "not_in" ] ) ) {
                        static::addNotRule();
                        return;
                }

                static::add();
        }

        
        public static function add() {

                $element = Filter::getOption( "element", "field" );

                $condition = Filter::getOption( 'condition' );

                $data = Filter::getOption( 'value' );

                $field = static::getTableAlias() . ".`meta_value`";

                $comparison = Filter::getOption( 'comparison' );

                $rule = Filter::bulidRule( $field, $data, $condition, $comparison );

                Filter::addWhere( DB::wpdb()->prepare( static::getTableAlias() . ".`meta_key` = %s AND " . $rule, $element ) );
        }

        
        private static function addNotRule() {

                $element = Filter::getOption( "element", "field" );

                $condition = substr( Filter::getOption( "condition" ), 4 );

                $data = Filter::getOption( 'value' );

                $alias         = Helper::randStr( "wpie_" );
                $itemAlias     = $alias . "items";
                $itemMetaAlias = $alias . "itemmeta";

                $field = $itemMetaAlias . ".`meta_value`";

                $comparison = Filter::getOption( 'comparison' );

                $rule = Filter::bulidRule( $field, $data, $condition, $comparison );

                $subQuery = DB::wpdb()->prepare(
                        "SELECT " . $itemAlias . ".`order_id` FROM " . DB::table( 'woocommerce_order_items' ) . " AS " . $itemAlias .
                        " LEFT JOIN " . DB::table( 'woocommerce_order_items' ) . " AS " . $itemMetaAlias . " ON (" . $itemAlias . ".`order_item_id` = " . $itemMetaAlias . ".`order_item_id`)" .
                        " WHERE  " . $itemAlias . ".`order_item_type` = 'line_item'   AND " . $itemMetaAlias . ".`meta_key` = %s AND " . $rule,
                        $element
                );

                Filter::addWhere( static::getOrderTableAlias() . ".`id` NOT IN(" . $subQuery . ") AND " . static::getOrderTableAlias() . ".`" . static::getTableAliasField() . "` NOT IN(" . $subQuery . ")" );
        }

        
        public static function addJoinQuery() {

                if ( static::$isJoinQueryAdded ) {
                        return;
                }

                static::$isJoinQueryAdded = true;

                Item::addJoinQuery();

                $itemAlias = Item::getTableAlias();

                Filter::addJoin( "LEFT JOIN " . DB::table( 'woocommerce_order_itemmeta' ) . " AS " . static::getTableAlias() . " ON (" . $itemAlias . ".`order_item_id` = " . static::getTableAlias() . ".`order_item_id`)" );
        }
        
        
        
        public static function getOrderTableAlias() {

                return Order::getTableAlias();
        }

        
        public static function getTableAliasField() {

                return 'parent_order_id';
        }

}
