<?php



namespace WpieApp\Extensions\Export\YoastSeo\Controller\Items\Post\Fields;

use WpieApp\Modules\Export\Controller\Settings;
use WpieApp\Modules\Export\Controller\Items\Base\Fields\InterfaceField;
use WpieApp\Modules\Export\Controller\Items\Post\Fields\Meta as PostMeta;

defined( 'WPIE__FILE__' ) || exit;


class Seo implements InterfaceField {

        
        const FIELD_TYPE = "yoast-seo";

        
        public static function get() {

                $fields = [
                        "title"      => \esc_html__( "Yoast SEO", 'wp-import-export' ),
                        "priority"   => 28,
                        "isFiltered" => false,
                        "data"       => self::getFields()
                ];

                
                return \apply_filters( 'Wpie/Export/Post/Fields/YoastSeo', $fields, Settings::getContentType() );
        }

        
        protected static function getFields() {

                return array_merge(
                        self::getGeneralFields(),
                        self::getSocialFields(),
                        self::getAdvancedFields(),
                        self::getSchemaFields(),
                        News::get(),
                        Video::get()
                );
        }

        
        protected static function getGeneralFields() {

                return [
                        //General
                        [ 'label' => 'SEO Title', 'type' => PostMeta::FIELD_TYPE, 'element' => '_yoast_wpseo_title' ],
                        [ 'label' => 'SEO Description', 'type' => PostMeta::FIELD_TYPE, 'element' => '_yoast_wpseo_metadesc' ],
                        [ 'label' => 'SEO Focus keyphrase', 'type' => PostMeta::FIELD_TYPE, 'element' => '_yoast_wpseo_focuskw' ],
                        [ 'label' => 'SEO Related keyphrases', 'type' => PostMeta::FIELD_TYPE, 'element' => '_yoast_wpseo_focuskeywords' ],
                        [ 'label' => 'SEO Keyphrase Synonyms', 'type' => PostMeta::FIELD_TYPE, 'element' => '_yoast_wpseo_keywordsynonyms' ],
                        [ 'label' => 'SEO Is Cornerstone Content', 'type' => PostMeta::FIELD_TYPE, 'element' => '_yoast_wpseo_is_cornerstone' ],
                        [ 'label' => 'SEO Score', 'type' => PostMeta::FIELD_TYPE, 'element' => '_yoast_wpseo_content_score' ],
                        [ 'label' => 'SEO Estimate Reading Time Minutes', 'type' => PostMeta::FIELD_TYPE, 'element' => '_yoast_wpseo_estimated-reading-time-minutes' ]
                ];
        }

        
        protected static function getSocialFields() {

                return [
                        //Facebook
                        [ 'label' => 'SEO Facebook Title', 'type' => PostMeta::FIELD_TYPE, 'element' => '_yoast_wpseo_opengraph-title' ],
                        [ 'label' => 'SEO Facebook Description', 'type' => PostMeta::FIELD_TYPE, 'element' => '_yoast_wpseo_opengraph-description' ],
                        [ 'label' => 'SEO Facebook Image', 'type' => PostMeta::FIELD_TYPE, 'element' => '_yoast_wpseo_opengraph-image' ],
                        //Twitter
                        [ 'label' => 'SEO Twitter Title', 'type' => PostMeta::FIELD_TYPE, 'element' => '_yoast_wpseo_twitter-title' ],
                        [ 'label' => 'SEO Twitter Description', 'type' => PostMeta::FIELD_TYPE, 'element' => '_yoast_wpseo_twitter-description' ],
                        [ 'label' => 'SEO Twitter Image', 'type' => PostMeta::FIELD_TYPE, 'element' => '_yoast_wpseo_twitter-image' ]
                ];
        }

        
        protected static function getAdvancedFields() {

                return [
                        // Robots Meta
                        [ 'label' => 'SEO Robots No Index', 'type' => PostMeta::FIELD_TYPE, 'element' => '_yoast_wpseo_meta-robots-noindex' ],
                        [ 'label' => 'SEO Robots No Follow', 'type' => PostMeta::FIELD_TYPE, 'element' => '_yoast_wpseo_meta-robots-nofollow' ],
                        [ 'label' => 'SEO Robots No Archive', 'type' => self::FIELD_TYPE, 'element' => 'robots-noarchive' ],
                        [ 'label' => 'SEO Robots No Image Index', 'type' => self::FIELD_TYPE, 'element' => 'robots-noimageindex' ],
                        [ 'label' => 'SEO Robots No Snippet', 'type' => self::FIELD_TYPE, 'element' => 'robots-nosnippet' ],
                        [ 'label' => 'SEO Breadcrumbs Title', 'type' => PostMeta::FIELD_TYPE, 'element' => '_yoast_wpseo_bctitle' ],
                        [ 'label' => 'SEO Canonical URL', 'type' => PostMeta::FIELD_TYPE, 'element' => '_yoast_wpseo_canonical' ]
                ];
        }

        
        protected static function getSchemaFields() {

                $schema = [
                        // Schema
                        [ 'label' => 'SEO Schema Page type', 'type' => PostMeta::FIELD_TYPE, 'element' => '_yoast_wpseo_schema_page_type' ],
                ];

                if ( 'wc' !== Settings::get( 'category' ) || 'product' !== Settings::get( 'content_type' ) ) {
                        $schema[] = [ 'label' => 'SEO Schema Article type', 'type' => PostMeta::FIELD_TYPE, 'element' => '_yoast_wpseo_schema_article_type' ];
                }
                
                return $schema;
        }
}
