<?php



namespace WpieApp\Extensions\Import\Acf\Controller\Items\Base\Engines;

use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\Controller\Items\Base\DataCenter;
use WpieApp\Modules\Import\Controller\Items\Base\Engines\Images\Source;
use WpieApp\Modules\Import\Controller\Items\Base\Engines\Images\Gallery;

defined( 'WPIE__FILE__' ) || exit;


class Choice extends Base {

        
        protected static $fieldTypes = [ 'button_group', 'checkbox', 'acfe_countries', 'acfe_currencies', 'acfe_image_selector', 'acfe_languages', 'radio', 'select', 'true_false' ];

        
        public static function getData() {

                switch ( static::$fieldType ) {

                        case 'true_false':
                                static::$data = (Helper::detectBoolVal( static::$data ) !== false);
                                break;

                        case 'select':
                                static::$data = static::getSelect();
                                break;

                        case 'radio':
                        case 'button_group':
                        case 'acfe_image_selector':
                                static::$data = static::getChoice();
                                break;

                        case 'checkbox':
                                static::$data = static::getChoices();
                                break;

                        case 'acfe_countries':
                        case 'acfe_currencies':
                        case 'acfe_languages':
                                self::updateChoices();
                                static::$data = static::getChoices();
                                break;
                }

                return parent::getData();
        }

        
        public static function getSelect() {

                $multiple = isset( static::$field[ 'multiple' ] ) ? \absint( static::$field[ 'multiple' ] ) : 0;

                return (1 === $multiple) ? static::getChoices() : static::getChoice();
        }

        
        private static function updateChoices() {

                $field = \acf_prepare_field( static::$field );

                static::$field [ 'choices' ] = isset( $field [ 'choices' ] ) ? $field [ 'choices' ] : static::$field [ 'choices' ];
        }

        
        public static function getChoice() {

                return Helper::arrTostr( static::findData( [ static::$data ] ) );
        }

        
        public static function getChoices() {

                $separator = DataCenter::get( 'acf/' . static::$key . '/separator' );

                $data = Helper::strToArr( static::$data, Helper::isNonEmptyStr( $separator ) ? $separator : '||' );

                return static::findData( $data );
        }

        
        public static function findData( $data = [] ) {

                $choices = isset( static::$field [ 'choices' ] ) ? static::$field [ 'choices' ] : [];

                if ( !Helper::isNonEmptyArray( $choices ) ) {
                        return [];
                }

                $data = array_map( 'trim', $data );

                $result = [];

                foreach ( $choices as $key => $val ) {

                        if ( in_array( $key, $data ) || in_array( $val, $data ) ) {
                                $result[] = $key;
                        }
                }

                return array_unique( $result );
        }
}
