<?php



namespace WpieApp\Extensions\Import\Acf\Controller\Items\Base\Fields;

use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\Controller\Settings;
use WpieApp\Extensions\Import\Acf\Controller\Items\Base\Field as AcfField;

defined( 'WPIE__FILE__' ) || exit;


class Acf {

        
        public static function getFieldGroupArg() {
                return [];
        }

        
        public static function getLocationFilters() {
                return [];
        }

        
        public static function get() {

                if ( !function_exists( '\acf_get_field_groups' ) || !function_exists( '\acf_get_fields' ) ) {
                        return [];
                }

                $groups = static::getFieldGroups();

                if ( !Helper::isNonEmptyArray( $groups ) ) {
                        return;
                }

                $acfFields = [];

                $priority = 31.001;

                foreach ( $groups as $group ) {

                        $key = isset( $group[ 'key' ] ) ? $group[ 'key' ] : (isset( $group[ 'ID' ] ) ? $group[ 'ID' ] : "");

                        $fields = static::getFields( $group );

                        if ( !Helper::isNonEmptyArray( $fields ) ) {
                                continue;
                        }

                        $title = isset( $group[ 'title' ] ) ? $group[ 'title' ] : "";

                        $acfFields[ 'acf-' . $key ] = [
                                "label"        => __( 'ACF', 'wp-import-export' ) . " - " . $title,
                                "class"        => "wpie-acf-fields",
                                "order"        => $priority,
                                "pro-backdrop" => WPIE_PRO ? false : true,
                                "blocks"       => $fields
                        ];

                        $priority = $priority + 0.001;
                }

                
                return \apply_filters( 'Wpie/Import/Fields/Acf', $acfFields, Settings::getContentType() );
        }

        
        public static function getFieldGroups() {

                static::addRemoveLocationFilters();

                $groups = \acf_get_field_groups( static::getFieldGroupArg() );

                static::addRemoveLocationFilters( "remove" );

                return $groups;
        }

        
        public static function addRemoveLocationFilters( $action = '' ) {

                $filters = static::getLocationFilters();

                if ( !Helper::isNonEmptyArray( $filters ) ) {
                        return;
                }

                $fn = ("remove" === $action ? "remove_filter" : "add_filter");

                foreach ( $filters as $filter ) {
                        $fn( "acf/location/rule_match/" . $filter, '__return_true', 99999 );
                }
        }

        
        public static function getFields( $group = [] ) {

                $fields = \acf_get_fields( $group );

                if ( !Helper::isNonEmptyArray( $fields ) ) {
                        return [];
                }

                $data = [];

                $order = 5;

                foreach ( $fields as $field ) {

                        $type = isset( $field[ 'type' ] ) ? $field[ 'type' ] : "";

                        if ( in_array( $type, [ 'acfe_button', 'acfe_hidden', 'acfe_recaptcha', 'accordion', 'message', 'tab', 'acfe_column', 'acfe_dynamic_render' ] ) ) {
                                continue;
                        }

                        $key = AcfField::getKey( $field );

                        $field[ 'key' ] = $key;

                        $data[ "acf/" . $key ] = Field::get( $field, $order );

                        $order = $order + 5;
                }

                return $data;
        }
}
