<?php



namespace WpieApp\Extensions\Import\WooCommerce\Controller\Items\Product;

use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\Controller\Settings;
use WpieApp\Modules\Import\Controller\Items\Post\AutoDetectAlternative as Base;

defined( 'WPIE__FILE__' ) || exit;


class AutoDetectAlternative extends Base {

        
        protected static function processField( $field = '' ) {

                parent::processField( $field );

                static::updateVariations( $field );

                static::updateStandard( $field );

                static::updateLinkedProducts( $field );

                static::updateStock( $field );

                static::updateType( $field );
        }

        
        protected static function updateStandard( $field = "" ) {

                $fields = [
                        'name'             => 'title',
                        'description'      => 'content',
                        'shortdescription' => 'excerpt',
                ];

                if ( !isset( $fields[ $field ] ) || AutoDetect::hasField( 'standard/' . $fields[ $field ] ) ) {
                        return;
                }

                AutoDetect::update( 'standard/' . $fields[ $field ], $field );
        }

        
        protected static function updateVariations( $field = "" ) {

                $fields = [
                        'parent' => 'parent',
                ];

                if ( !isset( $fields[ $field ] ) || Helper::isNonEmptyStr( AutoDetect::getField( 'variation/method/parent-child/' . $fields[ $field ] ) ) ) {
                        return;
                }

                AutoDetect::updateField( 'variation/method/option', 'parent-child', false );
                AutoDetect::updateField( 'variation/method/parent-child/' . $fields[ $field ], $field );
                AutoDetect::updateList( 'variation/method' );
        }

        
        protected static function updateLinkedProducts( $field = "" ) {

                $fields = [
                        'up-sells'    => 'upsells',
                        'cross-sells' => 'cross-sells',
                ];

                if ( !isset( $fields[ $field ] ) || AutoDetect::hasField( 'linked-products/' . $fields[ $field ] ) ) {
                        return;
                }

                AutoDetect::update( 'linked-products/' . $fields[ $field ], $field );
        }

        
        protected static function updateStock( $field = "" ) {

                $fields = [
                        '_sku'              => 'sku',
                        '_low_stock_amount' => 'low-stock-threshold'
                ];

                if ( !isset( $fields[ $field ] ) || AutoDetect::hasField( 'stock/' . $fields[ $field ] ) ) {
                        return;
                }

                AutoDetect::update( 'stock/' . $fields[ $field ], $field );
        }

        
        protected static function updateType( $field = "" ) {

                $fields = [
                        'producttype' => 'product-type',
                ];

                if ( !isset( $fields[ $field ] ) || AutoDetect::hasField( 'type/' . $fields[ $field ] ) ) {
                        return;
                }

                AutoDetect::update( 'type/' . $fields[ $field ], $field );
        }
}
