<?php



namespace WpieApp\Extensions\Import\WooCommerce\Controller\Items\Product;

use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\Controller\Settings;
use WpieApp\Modules\Import\Controller\Items\Base\Logger;
use WpieApp\Modules\Import\Controller\Items\Post\Engine as PostEngine;
use WpieApp\Extensions\Import\WooCommerce\Controller\Items\Product\Engines\Product;
use WpieApp\Extensions\Import\WooCommerce\Controller\Items\Product\Engines\Variable;
use WpieApp\Extensions\Import\WooCommerce\Controller\Items\Product\Engines\Meta;
use WpieApp\Modules\Import\Controller\Items\Post\DataCenter;

defined( 'WPIE__FILE__' ) || exit;


class Engine extends PostEngine {

        
        private static $isVariation = false;

        
        public static function updateEngine() {

                VariationsEngine::update();

                self::$isVariation = VariationsEngine::isVariation();
        }

        
        public static function import() {

                if ( !parent::import() ) {
                        return false;
                }

                if ( self::$isVariation ) {
                        return VariationsEngine::import();
                }

                $isSuccess = Product::import();

                if ( $isSuccess ) {
                        Variable::update();
                }

                return $isSuccess;
        }

        
        protected static function updatePost() {

                if ( !self::$isVariation ) {
                        return parent::updatePost();
                }

                return VariationsEngine::updatePost();
        }

        
        protected static function preparePost() {

                if ( self::$isVariation ) {
                        return VariationsEngine::preparePost();
                }

                return parent::preparePost();
        }

        
        protected static function updateMeta() {

                Meta::import();
        }

        
        public static function searchDuplicates() {

                if ( !VariationsEngine::parentHasChild() ) {
                        return 0;
                }

                $searchMethod = DataCenter::get( "search/method" );

                $postType = [ 'product', 'product_variation' ];

                $metaValue = '';

                switch ( $searchMethod ) {

                        case "sku":
                                $metaValue = DataCenter::get( "search/sku" );
                                if ( !Helper::isNonEmptyStr( $metaValue ) ) {
                                        $metaValue = DataCenter::get( "stock/sku/data" );
                                }
                                break;
                        case "auto":
                                $metaValue = DataCenter::get( "stock/sku/data" );
                                break;
                }


                $id = 0;

                if ( Helper::isNonEmptyStr( $metaValue ) ) {
                        $id = Search::getPostIdByMeta( '_sku', $metaValue, $postType );
                }

                $id = VariationsEngine::validateSearch( $id );

                if ( ( $id < 1 && self::$isVariation && !in_array( $searchMethod, [ 'meta', 'id' ] )) || 'sku' === $searchMethod ) {
                        return 0;
                }

                if ( $id < 1 ) {
                        $id = parent::searchDuplicates();
                }

                return $id;
        }
}
