<?php



namespace WpieApp\Extensions\Import\WooCommerce\Controller\Items\Product\Engines\Variable;

use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\Controller\Settings;
use WpieApp\Modules\Import\Controller\Items\Base\Logger;
use WpieApp\Modules\Import\Controller\Items\Post\DataCenter;

defined( 'WPIE__FILE__' ) || exit;


class Log {

        
        private static $fieldSeparator = '~|=|~';

        
        private static $lineSeparator = '||~||~||';

        
        private static $log = [];

        
        private static $fp = null;

        
        public static function add() {

                $field = self::getField();

                if ( !Helper::isNonEmptyStr( $field ) ) {
                        return;
                }

                if ( !self::load() ) {
                        return;
                }

                self::$log[ DataCenter::getId() ] = $field;

                $data = DataCenter::getId() . self::$fieldSeparator . $field . self::$lineSeparator;

                fwrite( self::$fp, $data );
        }

        
        public static function get( $option = 'data' ) {

                $field = self::getField( $option );

                if ( !Helper::isNonEmptyStr( $field ) ) {
                        return 0;
                }

                if ( !self::load() ) {
                        return 0;
                }

                $id = array_search( $field, self::$log );

                return $id === false ? 0 : $id;
        }

        
        private static function getField( $option = 'data' ) {

                $method = DataCenter::get( "variation/method/option" );

                if ( 'attribute' === $method ) {
                        return;
                }

                if ( 'parent' === $option && 'parent-child' === $method ) {
                        return DataCenter::get( "variation/method/parent-child/parent" );
                }

                return DataCenter::get( "variation/method/" . $method . "/data" );
        }

        
        private static function load() {

                if ( is_resource( self::$fp ) ) {
                        return true;
                }

                $file = Helper::pathJoin( Settings::getCurrentDir( 'log' ), 'products.log' );

                Settings::createImportDir( 'log' );

                self::$fp = fopen( $file, 'a+' );

                if ( self::$fp === false ) {
                        // Handle error opening the file
                        Logger::log( "<strong>" . __( "ERROR", 'wp-import-export' ) . "</strong> : can't open variable key log file" );
                        return false;
                }

                $filesize = filesize( $file );

                if ( 0 === $filesize ) {
                        return true;
                }

                fseek( self::$fp, 0 );

                // Read the existing content of the file
                $fileContent = fread( self::$fp, $filesize );

                if ( !Helper::isNonEmptyStr( $fileContent ) ) {
                        return true;
                }

                $logs = Helper::strToArr( $fileContent, self::$lineSeparator );

                foreach ( $logs as $log ) {

                        if ( !Helper::isNonEmptyStr( $log ) ) {
                                continue;
                        }

                        $info = Helper::strToArr( $log, self::$fieldSeparator );

                        if ( !is_array( $info ) || count( $info ) !== 2 ) {
                                continue;
                        }

                        $id = isset( $info[ 0 ] ) ? $info[ 0 ] : '';

                        self::$log[ $id ] = isset( $info[ 1 ] ) ? $info[ 1 ] : '';
                }

                unset( $fileContent, $logs, $file );

                return true;
        }

}
