<?php



namespace WpieApp\Extensions\Import\Wpml\Controller\Items\Term;

use WPML_Terms_Translations;
use WpieApp\Core\Utils\DB;
use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\Controller\Items\Term\Search as Term;
use WpieApp\Extensions\Import\Wpml\Controller\Items\Base\Filters as BaseFilters;

defined( 'WPIE__FILE__' ) || exit;


class Filters extends BaseFilters {

        
        protected static $isInit = false;

        
        protected static function remove() {

                global $sitepress;

                \remove_filter( 'get_terms_args', [ $sitepress, 'get_terms_args_filter' ] );
                \remove_filter( 'get_term', [ $sitepress, 'get_term_adjust_id' ], 1 );
                \remove_filter( 'terms_clauses', [ $sitepress, 'terms_clauses' ] );

                \remove_action( 'create_term', [ $sitepress, 'create_term' ], 1 );
                \remove_action( 'edit_term', [ $sitepress, 'create_term' ], 1 );

                \remove_action( 'set_object_terms', [ '\WPML_Terms_Translations', 'set_object_terms_action' ], 10 );
        }

        
        protected static function add() {

                \add_filter( 'terms_clauses', [ __CLASS__, 'termsClauses' ], 10, 3 );

                \add_filter( 'wp_unique_term_slug', [ __CLASS__, 'uniqueSlug' ], 10, 3 );
        }

        
        public static function addJoin() {

                if ( !Helper::isNonEmptyStr( static::getLanguage() ) ) {
                        return '';
                }

                return ' LEFT JOIN ' . DB::table( 'icl_translations' ) . '  AS ' . static::getTableAlias() . ' ON (tt.`term_taxonomy_id` = ' . static::getTableAlias() . ".`element_id` )";
        }

        
        public static function addWhere( $taxonomies = [] ) {

                if ( !Helper::isNonEmptyStr( static::getLanguage() ) ) {
                        return '';
                }

                $taxonomies = array_map( function ( $item ) {
                        return 'tax_' . $item;
                }, $taxonomies );

                $elementType = DB::prepareData( $taxonomies );

                $query = "  " . static::getTableAlias() . ".`element_type` IN (" . $elementType . ") AND " . static::getTableAlias() . ".`language_code` IN ('" . static::getLanguage() . "') ";

                return ' AND (' . $query . ') ';
        }

        
        public static function getTranslation( $lang, $value, $taxonomy ) {

                static::$language = $lang;

                $term = Term::findTerm( 'all', $value, $taxonomy );

                static::$language = '';

                return $term;
        }

        
        public static function termsClauses( $clauses, $taxonomies, $args ) {

                if ( !Helper::isNonEmptyArray( $taxonomies ) ) {
                        return $clauses;
                }

                $clauses[ 'join' ] .= static::addJoin();

                $clauses[ 'where' ] .= static::addWhere( $taxonomies );

                return $clauses;
        }

        
        public static function uniqueSlug( $slug, $term, $original_slug ) {

                return WPML_Terms_Translations::term_unique_slug( $slug, $term->taxonomy, static::getLanguage() );
        }

        
        public static function update( $lang ) {

                static::$language = $lang;

                static::init();
        }
}
