<?php



namespace WpieApp\Extensions;

use WpieApp\Core\Helpers\Helper;

defined( 'WPIE__FILE__' ) || exit;


class Manager {

        
        public static function load() {

                $activeModule = Helper::getActiveModule();

                self::initBackground( 'Import' );

                self::initBackground( 'Export' );

                if ( !in_array( $activeModule, [ 'Import', 'Export' ] ) ) {
                        return;
                }

                self::initMiddlewares( $activeModule );

                Assets::enqueue();
        }

        
        public static function loadExportExtensions() {

                self::initMiddlewares( 'Export' );
        }

        
        private static function initMiddlewares( $activeModule = '' ) {

                $findMiddlewareClasses = glob( WPIE_EXTENSIONS_DIR . '/' . $activeModule . '/*/Middleware.php' );

                if ( !Helper::isNonEmptyArray( $findMiddlewareClasses ) ) {
                        return;
                }

                $modulesDir = str_replace( '\\', '/', realpath( WPIE_EXTENSIONS_DIR . DIRECTORY_SEPARATOR . $activeModule ) );

                foreach ( $findMiddlewareClasses as $middlewareClass ) {
                        $middlewareClass = str_replace( '\\', '/', realpath( $middlewareClass ) );

                        if ( strpos( $middlewareClass, $modulesDir ) !== 0 ) {
                                continue;
                        }
                        $getModuleName = substr( $middlewareClass, strlen( rtrim( $modulesDir, '/' ) ) + 1 );
                        $getModuleName = explode( '/', $getModuleName );

                        $moduleName = $getModuleName[ 0 ];

                        $middlewareClassName = "\\WpieApp\\Extensions\\{$activeModule}\\{$moduleName}\\Middleware";

                        if ( !class_exists( $middlewareClassName ) ) {
                                continue;
                        }

                        new $middlewareClassName();
                }
        }

        
        private static function initBackground( $activeModule = '' ) {

                $findMiddlewareClasses = glob( WPIE_EXTENSIONS_DIR . '/' . $activeModule . '/*/Background.php' );

                if ( !Helper::isNonEmptyArray( $findMiddlewareClasses ) ) {
                        return;
                }

                $modulesDir = str_replace( '\\', '/', realpath( WPIE_EXTENSIONS_DIR . DIRECTORY_SEPARATOR . $activeModule ) );

                foreach ( $findMiddlewareClasses as $BGClass ) {
                        $BGClass = str_replace( '\\', '/', realpath( $BGClass ) );

                        if ( strpos( $BGClass, $modulesDir ) !== 0 ) {
                                continue;
                        }
                        $getModuleName = substr( $BGClass, strlen( rtrim( $modulesDir, '/' ) ) + 1 );
                        $getModuleName = explode( '/', $getModuleName );

                        $moduleName = $getModuleName[ 0 ];

                        $BGClassName = "\\WpieApp\\Extensions\\{$activeModule}\\{$moduleName}\\Background";

                        if ( !class_exists( $BGClassName ) ) {
                                continue;
                        }

                        new $BGClassName();
                }
        }
}
