<?php



namespace WpieApp\Modules\Export\Controller\Items\Base\DataCenters;

use WpieApp\Core\Utils\Date;
use WpieApp\Core\Parser\Snippet;
use WpieApp\Core\Helpers\Helper;
use WpieApp\Core\Resource\Resource;
use WpieApp\Modules\Export\Controller\Settings;
use WpieApp\Modules\Export\Controller\Items\Base\RecordsPerIteration;

defined( 'WPIE__FILE__' ) || exit;


class Base {

        
        private static $data = [];

        
        private static $field = [];

        
        protected static $id = 0;

        
        protected static $item = null;

        
        protected static function processData() {
                return '';
        }

        
        protected static function setItem() {
                return false;
        }

        
        public static function getItem() {
                return self::$item;
        }

        
        public static function getId() {
                return self::$id;
        }

        
        public static function init( $data = [], $action = "export" ) {


                if ( !Helper::isNonEmptyArray( $data ) ) {
                        return false;
                }

                Field::init();

                if ( !Field::hasFields() ) {
                        Settings::set( "status", "failed" );
                        Settings::setOption( "error", __( 'Export fields are missing', 'wp-import-export' ) );
                        return;
                }

                $data = array_map( "absint", $data );

                if ( !Helper::isNonEmptyArray( $data ) ) {
                        return false;
                }

                if ( $action === "preview" ) {
                        return static::getPreview( $data );
                }

                return static::processExport( $data );
        }

        
        private static function getPreview( $data = [] ) {

                $id = array_shift( $data );

                if ( absint( $id ) < 1 ) {
                        return [];
                }

                static::setItemData( absint( $id ) );

                $labels = static::getLabels();

                return [ 'labels' => array_values( $labels ), 'data' => array_values( self::$data ) ];
        }

        
        private static function processExport( $data = [] ) {

                static::start();

                foreach ( $data as $id ) {

                        if ( Resource::isExceeded() ) {
                                break;
                        }

                        if ( $id < 1 ) {
                                continue;
                        }

                        static::startRecord();

                        static::setItemData( $id );

                        static::saveFieldData();

                        static::endRecord();

                        Settings::updateLog( 'exported' );
                }

                RecordsPerIteration::set();

                static::complete();

                return Settings::getLog( 'processed' );
        }

        
        private static function setItemData( $id ) {

                if ( absint( $id ) < 1 ) {
                        return [];
                }

                self::$id = absint( $id );

                if ( !static::setItem( self::$id ) ) {
                        return [];
                }

                static::processField();
        }

        
        private static function processField() {

                self::$data = [];

                foreach ( Field::getAll() as $key => $field ) {

                        $field = Field::getCustom( $key, $field );

                        if ( isset( $field[ 'isMultiField' ] ) && Helper::toInt( $field[ 'isMultiField' ] ) === 1 ) {

                                $data = static::processMultiField( $field );
                        } else {

                                $data = static::processSingleField( $field );
                        }

                        if ( isset( $field[ 'phpFunc' ] ) && Helper::isNonEmptyStr( $field[ 'phpFunc' ] ) ) {
                                $data = static::applyPhpFunc( $data, $field[ 'phpFunc' ] );
                        }

                        self::$data[ $key ] = Helper::toString( $data );
                }
        }

        
        private static function saveFieldData() {

                
                $data = \apply_filters( 'Wpie/Export/Data/Final', self::$data );

                Writer::add( array_values( $data ) );
        }

        
        private static function processDate( $data = "" ) {

                if ( Helper::isEmpty( $data ) ) {
                        return $data;
                }

                $isDate = static::getFieldOption( 'isDate' );

                if ( $isDate !== true ) {
                        return $data;
                }
                $dateFormat = static::getFieldOption( 'dateFormat' );

                $hasMultiVal = static::getFieldOption( 'hasMultiVal' );

                $separator = static::getFieldOption( 'separator' );

                $separator = Helper::isNonEmptyStr( $separator ) ? $separator : "||";

                if ( $hasMultiVal !== true ) {

                        return Date::get( $data, $dateFormat );
                }

                $values = Helper::strToArr( $data, $separator );

                $newData = [];

                foreach ( $values as $val ) {

                        $newData[] = Helper::isNonEmptyStr( $val ) ? Date::get( $val, $dateFormat ) : "";
                }

                return Helper::arrTostr( $newData, $separator );
        }

        
        protected static function processSingleField( $field = [] ) {

                self::$field = $field;

                if ( static::getFieldOption( "type" ) === "text" ) {
                        return static::getFieldOption( "data" );
                }

                $type = static::getFieldOption( "type" );

                
                $data = \apply_filters( 'Wpie/Export/Base/Data', static::processData(), $type );

                $data = is_array( $data ) ? static::handleArr( $data, "||" ) : $data;

                return static::processDate( $data );
        }

        
        private static function processMultiField( $fieldOptions = [] ) {

                $multiField = isset( $fieldOptions[ 'multiField' ] ) ? $fieldOptions[ 'multiField' ] : "";

                if ( Helper::isEmptyStr( $multiField ) ) {
                        return "";
                }

                $fields = Snippet::parse( $multiField );

                if ( !Helper::isNonEmptyArray( $fields ) ) {
                        return $multiField;
                }

                $labels = [ "{}" ];

                $data = [ "" ];

                foreach ( $fields as $fieldLabel ) {

                        $labels[] = "{" . $fieldLabel . "}";

                        $field = Field::search( $fieldLabel );

                        $fieldData = "";

                        if ( Helper::isNonEmptyArray( $field ) ) {

                                $field[ 'isMultiField' ] = 1;

                                $fieldData = static::processSingleField( $field );
                        }

                        $data[] = $fieldData;
                }

                return strtr( $multiField, array_combine( $labels, $data ) );
        }

        
        private static function getLabels() {

                $data = [];

                foreach ( Field::getAll() as $key => $field ) {

                        $fieldData = Field::getCustom( $key, $field );

                        $label = isset( $fieldData[ 'label' ] ) ? $fieldData[ 'label' ] : "";

                        $data[] = Helper::toString( $label );
                }

                return $data;
        }

        
        public static function getFieldOption( $option = "" ) {

                return Helper::isNonEmptyStr( $option ) && isset( self::$field[ $option ] ) ? self::$field[ $option ] : "";
        }

        
        protected static function getFieldOptions() {

                return self::$field;
        }

        
        public static function handleArr( $arr, $sep = "," ) {

                if ( Helper::isEmpty( $arr ) ) {
                        return "";
                }

                if ( Helper::isNonEmptyArray( $arr ) ) {

                        $arr = (Helper::isAssociativeArray( $arr ) || Helper::isMultidimensional( $arr )) ? Helper::jsonEncode( $arr ) : Helper::arrTostr( $arr, $sep );
                }

                return $arr;
        }

        
        private static function applyPhpFunc( $data = "", $func = "" ) {

                if ( !Helper::isNonEmptyStr( Helper::sanitizeiKey( $func ) ) ) {
                        return $data;
                }

                $func = "\\" . Helper::sanitizeiKey( $func );

                if ( !function_exists( $func ) ) {
                        return $data;
                }

                try {
                        $data = $func( $data );
                } catch ( Exception $ex ) {
                        
                }

                return $data;
        }

        
        public static function start() {

                Settings::set( "status", "processing" );

                if ( Settings::getLog( "processed" ) === 0 ) {

                        Writer::add( static::getLabels() );

                        \do_action( "Wpie/Export/Items/Start" );
                }
        }

        
        public static function complete() {

                if ( Settings::get( "total" ) < 1 || Settings::getLog( "processed" ) < Settings::get( "total" ) ) {

                        Settings::set( "status", "waiting" );

                        return;
                }

                \do_action( "Wpie/Export/Items/End" );

                Settings::set( "status", "pre-completed" );
        }

        
        protected static function startRecord() {

                $record = Settings::getLog( "processed" ) + 1;

                \do_action( "Wpie/Export/Items/Record/Start", $record );
        }

        
        protected static function endRecord() {

                $record = Settings::getLog( "processed" );

                \do_action( "Wpie/Export/Items/Record/End", $record );
        }
}
