<?php



namespace WpieApp\Modules\Export\Controller\Items\Post;

use WpieApp\Core\Utils\DB;
use WpieApp\Modules\Export\Helpers\Helper;
use WpieApp\Modules\Export\Controller\Settings;
use WpieApp\Modules\Export\Controller\Items\Base\Engine\Base;

defined( 'WPIE__FILE__' ) || exit;


class Engine extends Base {

        
        protected static function getData() {

                
                \do_action( 'Wpie/Export/Post/Start', Settings::getContentType() );

                $query = static::buildQuery();

                if ( !Helper::isNonEmptyArray( $query ) || !isset( $query[ 'post_type' ] ) ) {
                        return false;
                }

                static::initFilter();

                self::addRemoveFilters();

                // Run query
                $post = new \WP_Query( $query );

                $data = $post->have_posts() ? $post->posts : [];

                self::addRemoveFilters( 'remove' );

                // Reset post data as before
                \wp_reset_postdata();

                if ( self::$action === "total" ) {
                        return Helper::isNonEmptyArray( $data ) && isset( $data[ 0 ] ) ? $data[ 0 ] : 0;
                }

                // Clear memory
                unset( $query, $post );

                return static::processData( $data );
        }

        
        protected static function processData( $data = [] ) {
                return DataCenter::init( $data, self::$action );
        }

        
        protected static function addRemoveFilters( $action = "add" ) {

                $fn = ($action === "remove" ? "remove_filter" : "add_filter");

                // Apply filter rules
                $fn( 'posts_where', [ static::class, 'filterWhere' ] );
                $fn( 'posts_join', [ __CLASS__, 'filterJoin' ] );

                //Apply filters for get only count
                $fn( 'posts_fields', [ __CLASS__, 'postsFields' ] );

                $fn( 'posts_groupby', [ __CLASS__, 'postsGroupby' ], 99999 );
        }

        
        protected static function initFilter() {

                
                \do_action( 'Wpie/Export/Post/Filter/Start', Settings::get( 'content_type' ) );

                Filter::init();

                
                \do_action( 'Wpie/Export/Post/Filter/Init', Settings::getContentType() );

                static::initBaseFilter();

                self::$where = Filter::getWhere();
                self::$join  = Filter::getJoin();
        }

        
        protected static function buildQuery() {

                $query = [
                        'post_type'   => Settings::getContentType(),
                        'post_status' => array_diff( array_keys( \get_post_stati() ), [ 'auto-draft' ] ),
                        'orderby'     => "ID",
                        'order'       => 'ASC',
                        'fields'      => 'ids',
                ];

                $preQuery = parent::buildQuery();

                if ( Helper::isNonEmptyArray( $preQuery ) ) {
                        $query = array_merge( $query, $preQuery );
                }

                if ( self::$action === "total" ) {
                        $query[ 'posts_per_page' ] = -1;
                } elseif ( self::$action === "preview" ) {
                        $query[ 'offset' ]         = Helper::toInt( Helper::_post( 'row' ) ) > 0 ? Helper::toInt( Helper::_post( 'row' ) ) - 1 : 0;
                        $query[ 'posts_per_page' ] = 1;
                } else {
                        $query[ 'offset' ]         = Settings::getLog( 'processed' );
                        $query[ 'posts_per_page' ] = Settings::recordsPerIteration();
                }

                
                return \apply_filters( 'Wpie/Export/Post/Query', $query, Settings::getContentType() );
        }

        
        public static function postsFields( $field = "" ) {

                $query = "DISTINCT " . DB::wpdb()->posts . ".ID";

                if ( self::$action === "total" ) {
                        return "COUNT(" . $query . ") as Total";
                }

                return $query;
        }

        
        public static function postsGroupby( $groupby = "" ) {

                return "";
        }
}
