<?php



namespace WpieApp\Modules\Export\Controller\Items\User;

use WpieApp\Core\Utils\DB;
use WpieApp\Modules\Export\Helpers\Helper;
use WpieApp\Modules\Export\Controller\Settings;
use WpieApp\Modules\Export\Controller\Items\Base\Engine\Base;

defined( 'WPIE__FILE__' ) || exit;


class Engine extends Base {

        
        protected static function getData() {

                
                \do_action( 'Wpie/Export/User/Start', Settings::getContentType() );

                $query = self::buildQuery();

                if ( !Helper::isNonEmptyArray( $query ) ) {
                        return false;
                }

                static::initFilter();
                static::addRemoveFilters();

                $users = new \WP_User_Query();

                $users->prepare_query( $query );

                if ( self::$action === "total" ) {

                        $users->query_fields = " COUNT( DISTINCT " . DB::wpdb()->users . ".ID ) as total ";
                } else {
                        $users->query_fields = " DISTINCT " . DB::wpdb()->users . ".ID ";
                }

                $users->query();

                $data = $users->get_results();

                static::addRemoveFilters( 'remove' );

                if ( self::$action === "total" ) {
                        return Helper::isNonEmptyArray( $data ) && isset( $data[ 0 ] ) ? $data[ 0 ] : 0;
                }

                // Clear memory
                unset( $query, $users );

                return DataCenter::init( $data, self::$action );
        }

        
        protected static function addRemoveFilters( $action = "add" ) {

                $fn = ($action === "remove" ? "remove_filter" : "add_filter");

                // Apply filter rules
                $fn( 'pre_user_query', [ static::class, 'addWhereJoin' ] );
        }

        
        private static function initFilter() {

                
                \do_action( 'Wpie/Export/User/Filter/Start', Settings::getContentType() );

                Filter::init();

                
                \do_action( 'Wpie/Export/User/Filter/Init', Settings::getContentType() );
                
                static::initBaseFilter();

                self::$where = Filter::getWhere();
                self::$join  = Filter::getJoin();
        }

        
        protected static function buildQuery() {

                $query = [
                        'orderby' => 'ID',
                        'order'   => 'ASC',
                        'fields'  => 'ids'
                ];
                
                 $preQuery = parent::buildQuery();

                if ( Helper::isNonEmptyArray( $preQuery ) ) {
                        $query = array_merge( $query, $preQuery );
                }

                if ( self::$action === "total" ) {
                        $query[ 'number' ] = 0;
                        $query[ 'offset' ] = 0;
                } elseif ( self::$action === "preview" ) {
                        $query[ 'offset' ] = Helper::toInt( Helper::_post( 'row' ) ) > 0 ? Helper::toInt( Helper::_post( 'row' ) ) - 1 : 0;
                        $query[ 'number' ] = 1;
                } else {
                        $query[ 'offset' ] = Settings::getLog( 'processed' );
                        $query[ 'number' ] = Settings::recordsPerIteration();
                }

                
                return \apply_filters( 'Wpie/Export/User/Query', $query, Settings::getContentType() );
        }

}
