<?php



namespace WpieApp\Modules\Import\Controller;

use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\Controller\File\Setup;
use WpieApp\Modules\Import\Controller\File\Filter;
use WpieApp\Modules\Import\Controller\File\Record;
use WpieApp\Modules\Import\Controller\Items\Manager as Items;
use WpieApp\Modules\Import\Controller\File\Parser\Manager as FileParser;

defined( 'WPIE__FILE__' ) || exit;


class Background {

        
        private static $hasCompleted = false;

        
        public static function run( $id = 0 ) {

                if ( absint( $id ) < 1 ) {
                        return;
                }

                Settings::load( $id );

                self::start();

                self::prepareImport();

                self::complete();
        }

        
        private static function prepareImport() {

                switch ( Settings::get( 'status' ) ) {
                        case "init":
                                self::reset();
                                self::downloadFile();
                                break;
                        case "download-completed":
                                self::processFile();
                                break;
                        case "proccess-file" :
                                self::parseFile();
                                break;
                        case "parse-completed":
                                self::applyFilters();
                                break;
                        case "filter-completed":
                                self::getTotal();
                                break;
                }

                Items::get();
        }

        
        private static function start() {

                \add_action( 'shutdown', [ __CLASS__, 'complete' ] );

                if ( Settings::get( "is_locked" ) === 1 ) {
                        return;
                }

                Settings::set( "is_locked", 1 );
        }

        
        public static function reset() {

                if ( 'completed' === Settings::getOption( 'template-reset-status' ) ) {
                        return;
                }

                Settings::setOption( 'template-reset-status', 'completed' );

                Settings::setOption( 'file/parser', '' );
        }

        
        public static function downloadFile() {

                $data = Downloader::init();

                if ( \is_wp_error( $data ) ) {

                        self::setError( $data->get_error_message() );
                }

                Settings::set( 'status', 'download-completed' );

                self::complete();
        }

        
        public static function processFile() {

                if ( !Helper::isArchive( Settings::getUploadFilePath() ) ) {
                        self::parseFile();
                        return;
                }

                $isFileSet = Setup::setFile( Settings::getOption( "file/path" ) );

                if ( \is_wp_error( $isFileSet ) ) {

                        self::setError( $isFileSet->get_error_message() );
                }

                Settings::set( 'status', 'proccess-file' );

                self::complete();
        }

        
        public static function parseFile() {

                $retry = Settings::getOption( "parser/retry", 0 );

                $retry = is_numeric( $retry ) ? absint( $retry ) : 0;

                $parser = FileParser::init( $retry );

                if ( \is_wp_error( $parser ) ) {

                        Settings::getOption( "parser/retry", ($retry + 1 ) );

                        if ( $retry === 0 ) {
                                self::$hasCompleted = true;

                                Settings::set( "is_locked", 0 );

                                Helper::ajaxError( [ "process" => Settings::get( "process" ), "id" => Settings::get( "id" ), "error" => __( 'unable to parse file', 'wp-import-export' ) ] );
                        }

                        self::setError( $parser->get_error_message() );
                }

                Settings::set( 'status', 'parse-completed' );

                self::complete();
        }

        
        public static function applyFilters() {

                if ( !Helper::isNonEmptyArray( Settings::getOption( "filter/rules" ) ) ) {
                        self::getTotal();
                        return;
                }

                $result = Filter::init();

                if ( \is_wp_error( $result ) ) {

                        self::setError( $result->get_error_message() );
                }
                if ( isset( $result[ 'status' ] ) && $result[ 'status' ] === "completed" ) {
                        Settings::set( 'status', 'filter-completed' );
                }

                self::complete();
        }

        
        public static function getTotal() {

                $total = Record::get( "getTotal" );

                if ( \is_wp_error( $total ) ) {

                        self::setError( $total->get_error_message() );
                }

                Settings::set( [ 'total' => $total, 'status' => 'waiting' ] );

                self::complete();
        }

        
        public static function setError( $error = "" ) {

                self::$hasCompleted = true;

                Settings::set( [ 'status' => 'failed', 'is_locked' => 0 ] );

                Settings::setOption( 'error', $error );

                $id = Settings::get( 'id' );

                $data = [ "process" => Settings::get( "process" ), "id" => Settings::get( 'id' ), 'error' => $error ];

                self::updateSchedule( Settings::get( 'parent' ) );

                Helper::ajaxError( $data );
        }

        
        private static function updateSchedule( $id = 0 ) {

                Settings::set( 'id', 0 );

                Settings::load( $id );

                Settings::setOption( 'schedule/failed', \absint( Settings::getOption( 'schedule/failed' ) ) + 1 );
        }

        
        public static function complete() {

                if ( self::$hasCompleted ) {
                        return;
                }

                self::$hasCompleted = true;

                if ( Settings::get( "is_locked" ) !== 0 ) {
                        Settings::set( "is_locked", 0 );
                }

                Helper::ajaxSuccess( [ "process" => Settings::get( "process" ), "id" => Settings::get( "id" ), "processed" => Settings::getLog( "processed" ) ] );
        }
}
