<?php



namespace WpieApp\Modules\Import\Controller\File\Records;

use WpieApp\Core\Helpers\Helper;
use WpieApp\Modules\Import\Controller\Settings;
use WpieApp\Core\Office\Reader\XML\XmlTags;
use WpieApp\Core\Office\Reader\XML\XmlArray;
use WpieApp\Core\Office\Reader\XML\XmlNode;
use WpieApp\Core\Office\Reader\XML\XmlRoot;
use WpieApp\Core\Office\Reader\XML\XmlTagCounter;

defined( 'WPIE__FILE__' ) || exit;


class Xml {

        
        public static function get( $action = "", $options = [] ) {

                $file = Settings::getFilePath();

                if ( in_array( $action, [ "getNodeList", "getLabels" ] ) ) {

                        return self::getTags( Settings::getImportFilePath() );
                }

                if ( "getFilterElements" === $action ) {

                        return self::getFilterElements( $file );
                }
                if ( "getRootList" === $action ) {

                        $nodes = isset( $options[ 'nodes' ] ) ? $options[ 'nodes' ] : [];

                        return self::getRoot( $nodes );
                }
                if ( "getTotal" === $action ) {

                        return self::getTotal( $file );
                }

                if ( in_array( $action, [ "getRow", "getNode" ] ) ) {

                        $node = isset( $options[ 'row' ] ) ? Helper::toInt( $options[ 'row' ] ) : 1;

                        return self::getNode( $file, $node );
                }
        }

        
        public static function getTags( $file = "" ) {

                $xml = new XmlTags();

                $isLoaded = $xml->load( $file );

                if ( \is_wp_error( $isLoaded ) ) {
                        return $isLoaded;
                }

                return $xml->getTags();
        }

        
        public static function getFilterElements( $file = "" ) {

                $xml = new XmlTags();

                $isLoaded = $xml->load( $file, [ 'root' => self::getFilterRoot() ] );

                if ( \is_wp_error( $isLoaded ) ) {
                        return $isLoaded;
                }

                return $xml->getFilterElements();
        }

        
        public static function getRoot( $nodes = [] ) {

                if ( !Helper::isNonEmptyArray( $nodes ) ) {
                        return [];
                }

                $roots = new XmlRoot();

                return $roots->getRoot( $nodes );
        }

        
        public static function getNode( $file = "", $node = 1 ) {

                $xml = new XmlArray();

                $isLoaded = $xml->load( $file, [ 'root' => self::getFilterRoot() ] );

                if ( is_wp_error( $isLoaded ) ) {
                        return $isLoaded;
                }

                return $xml->getNode( $node );
        }

        
        public static function getReader() {

                $file = Settings::getFilePath();

                $xml = new XmlNode();

                $isLoaded = $xml->load( $file, [ 'root' => self::getFilterRoot() ] );

                if ( is_wp_error( $isLoaded ) ) {
                        return $isLoaded;
                }

                return $xml;
        }

        
        public static function getTotal( $file = "" ) {

                $xml = new XmlTagCounter();

                $isLoaded = $xml->load( $file, [ 'root' => self::getFilterRoot() ] );

                if ( is_wp_error( $isLoaded ) ) {
                        return $isLoaded;
                }

                return $xml->getTotal();
        }

        
        public static function getFilterRoot() {

                $root = Settings::getOption( "data/root" );

                if ( Helper::isNonEmptyStr( $root ) ) {
                        return $root;
                }

                return Settings::getOption( "file/root" );
        }
}
