<?php




namespace WpieApp\Modules\Export\Controller\Items\Base\Filters;

use WpieApp\Core\Helpers\Helper;
use WpieApp\Core\Utils\DB;
use WpieApp\Core\Utils\Date;

defined( 'WPIE__FILE__' ) || exit;


class RuleParser {

        
        public static function bulidRule( $condition = "", $value = "", $isDate = false, $isIntVal = false ) {

                if ( Helper::isEmptyStr( $condition ) ) {
                        return "";
                }

                $rule = "";

                if ( ($isIntVal || $isDate) && in_array( $condition, [ 'greater', 'equals_or_greater', 'less', 'equals_or_less', 'equals', 'not_equals' ] ) ) {

                        if ( $isIntVal ) {

                                if ( !is_numeric( $value ) && Helper::toNumber( $value ) <= 0 ) {
                                        return false;
                                }

                                $newVal = DB::wpdb()->prepare( '%d', Helper::toNumber( $value ) );
                        } else {

                                $value = $isDate ? Date::get( $value ) : $value;

                                $newVal = DB::wpdb()->prepare( '%s', $value );

                                $newVal = $isDate ? " Date( " . $newVal . " ) " : $newVal;
                        }

                        $operator = self::getOperator( $condition );

                        $rule = Helper::isNonEmptyStr( $operator ) ? $operator . $newVal : "";
                }

                if ( Helper::isEmptyStr( $rule ) ) {

                        $rule = self::parseConditions( $condition, $value );
                }

                return $rule;
        }

        
        public static function parseConditions( $condition = "", $value = "" ) {

                $rule = "";

                switch ( $condition ) {

                        case 'equals':
                                $rule = DB::wpdb()->prepare( ' = %s ', $value );
                                break;
                        case 'not_equals':
                                $rule = DB::wpdb()->prepare( ' != %s ', $value );
                                break;
                        case 'contains':
                                $rule = DB::wpdb()->prepare( 'LIKE %s', "%" . DB::wpdb()->esc_like( $value ) . "%" );
                                break;
                        case 'not_contains':
                                $rule = DB::wpdb()->prepare( 'NOT LIKE %s', "%" . DB::wpdb()->esc_like( $value ) . "%" );
                                break;
                        case 'is_empty':
                                $rule = "IS NULL";
                                break;
                        case 'is_not_empty':
                                $rule = "IS NOT NULL";
                                break;
                        case 'in':
                        case 'not_in':

                                $inVal = [];

                                $newValue = Helper::strToArr( $value );

                                if ( Helper::isNonEmptyArray( $newValue ) ) {

                                        foreach ( $newValue as $val ) {
                                                $inVal[] = DB::wpdb()->prepare( '%s', $val );
                                        }
                                }
                                $inVal = Helper::isNonEmptyArray( $inVal ) ? implode( ",", $inVal ) : "";

                                $notIn = $condition === "not_in" ? "NOT" : "";

                                $rule = Helper::isNonEmptyStr( $value ) ? $notIn . " IN (" . $inVal . ")" : "";

                                break;
                }
                return $rule;
        }

        
        private static function getOperator( $name = "" ) {

                $operator = "";

                switch ( $name ) {

                        case 'greater':
                                $operator = " > ";
                                break;
                        case 'equals_or_greater':
                                $operator = " >= ";
                                break;
                        case 'less':
                                $operator = " < ";
                                break;
                        case 'equals_or_less':
                                $operator = " <= ";
                                break;
                        case 'equals':
                                $operator = " = ";
                                break;
                        case 'not_equals':
                                $operator = " != ";
                                break;
                }
                return $operator;
        }

}
