<?php



namespace WpieApp\Modules\Import\Controller\Items\Base\Search;

use WpieApp\Core\Utils\DB;
use WpieApp\Modules\Import\Helpers\Helper;

defined( 'WPIE__FILE__' ) || exit;


class Base {

        
        protected static $options = [];

        
        protected static $args = [];

        
        protected static $allowedKeys = [];

        
        protected static $dbTable = '';

        
        protected static $prefix;

        
        public static function search( $args = [], $options = [] ) {

                self::$args = $args;

                self::$options = $options;

                static::init();

                $query = static::generate( $args );

                return static::query( $query );
        }

        
        protected static function init() {
                
        }

        
        protected static function generate( $args = [] ) {

                if ( !Helper::isNonEmptyArray( $args ) ) {
                        return "";
                }

                $query = "";

                foreach ( $args as $arg ) {

                        $relation = isset( $arg[ 'relation' ] ) && trim( strtolower( $arg[ 'relation' ] ) ) === "or" ? 'OR' : 'AND';

                        $params = isset( $arg[ 'args' ] ) ? $arg[ 'args' ] : [];

                        if ( !Helper::isNonEmptyArray( $params ) ) {
                                continue;
                        }

                        if ( isset( $params[ 0 ] ) && isset( $params[ 0 ][ 'args' ] ) ) {
                                $queryArg = static::generate( $params );
                        } else {
                                $queryArg = static::processQuery( $params );
                        }

                        if ( '' === $queryArg ) {
                                continue;
                        }

                        if ( '' === $query ) {
                                $relation = "";
                        }

                        $query .= " " . $relation . " ( " . $queryArg . " ) ";
                }

                return $query;
        }

        
        protected static function processQuery( $args = [] ) {

                if ( !Helper::isNonEmptyArray( $args ) ) {
                        return "";
                }

                $query = "";

                foreach ( $args as $arg ) {

                        $relation = isset( $arg[ 'relation' ] ) && trim( strtolower( $arg[ 'relation' ] ) ) === "or" ? 'OR' : 'AND';

                        $queryArg = static::createQuery( $arg );

                        if ( '' === $queryArg ) {
                                continue;
                        }

                        if ( '' === $query ) {
                                $relation = "";
                        }

                        $query .= ' ' . $relation . ' ( ' . $queryArg . ' ) ';
                }

                return $query;
        }

        
        protected static function createQuery( $args = [] ) {

                if ( !Helper::isNonEmptyArray( $args ) ) {
                        return "";
                }

                $key = isset( $args[ 'key' ] ) ? static::fixKey( $args[ 'key' ] ) : "";

                if ( !Helper::isNonEmptyStr( $key ) ) {
                        return "";
                }

                $value = isset( $args[ 'value' ] ) ? $args[ 'value' ] : "";

                if ( isset( $args[ 'is_int' ] ) && $args[ 'is_int' ] === true ) {

                        $value = is_numeric( $value ) ? Helper::toNumber( $value ) : 0;

                        if ( isset( $args[ 'conditions' ] ) && is_array( $args[ 'conditions' ] ) && in_array( "positive_number_only", $args[ 'conditions' ] ) && $value < 1 ) {
                                return "";
                        }
                }

                $value = static::sanitize( $value, $key );

                return ' `' . static::$prefix . '`.`' . $key . '` IN (' . DB::prepareData( $value ) . ') ';
        }

        
        protected static function sanitize( $data = '', $key = '' ) {
                return $data;
        }

        
        protected static function fixKey( $key = "" ) {

                return $key;
        }

        
        protected static function query( $query = '' ) {

                if ( !Helper::isNonEmptyStr( $query ) || !Helper::isNonEmptyStr( self::$dbTable ) ) {
                        return 0;
                }

                $where = \apply_filters( 'Wpie/Import/Item/Query/Where', $query, static::$prefix );

                $join = \apply_filters( 'Wpie/Import/Item/Query/Join', '', static::$prefix );

                $limit = isset( self::$options[ 'limit' ] ) && absint( self::$options[ 'limit' ] ) > 0 ? absint( self::$options[ 'limit' ] ) : 1;

                $limitQuery = DB::wpdb()->prepare( 'LIMIT 0, %d', $limit );

                $results = DB::wpdb()->get_results(
                        'SELECT `' . static::$prefix . '`.`ID` FROM ' . self::$dbTable . ' as ' . static::$prefix
                        . ' ' . $join
                        . ' WHERE  ' . $where . ' ORDER BY `' . static::$prefix . '`.`ID` ASC ' . $limitQuery
                );

                if ( empty( $results ) ) {
                        return 0;
                }

                $ids = [];

                foreach ( $results as $row ) {

                        $ids[] = isset( $row->ID ) ? $row->ID : 0;
                }

                if ( $limit === 1 ) {
                        return $ids[ 0 ];
                }

                return $ids;
        }
}
