<?php



namespace WpieApp\Modules\Import\Controller\Items\Comment;

use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\Controller\Settings;
use WpieApp\Modules\Import\Controller\Items\Base\Logger;
use WpieApp\Modules\Import\Controller\Items\Base\Engine as BaseEngine;
use WpieApp\Modules\Import\Controller\Items\Comment\Engines\Standard;
use WpieApp\Modules\Import\Controller\Items\Comment\Engines\Author;
use WpieApp\Modules\Import\Controller\Items\Comment\Engines\Post;
use WpieApp\Modules\Import\Controller\Items\Comment\Engines\Extra;
use WpieApp\Modules\Import\Controller\Items\Comment\Engines\Meta;

defined( 'WPIE__FILE__' ) || exit;


class Engine extends BaseEngine {

        
        public static function import() {

                \do_action( "Wpie/Import/Comment/Engine/Start" );

                if ( !static::insertComment() ) {
                        return false;
                }

                static::afterAdd();

                static::updateComment();

                \do_action( "Wpie/Import/Comment/Engine/End" );

                return true;
        }

        
        protected static function afterAdd() {

                \do_action( "Wpie/Import/Comment/Engine/Add/After" );

                parent::afterAdd();
        }

        
        protected static function prepareComment() {

                $standard = Standard::get();

                $author = Author::get();

                $post = static::getPost();

                $extra = Extra::get();

                return array_merge( $standard, $author, $post, $extra );
        }

        
        protected static function getPost() {

                return Post::get();
        }

        
        protected static function setItem( $id = 0 ) {

                DataCenter::setId( $id );

                DataCenter::setItem( \get_comment( $id ) );
        }

        
        protected static function updateComment() {

                static::updateMeta();
        }

        
        protected static function updateMeta() {

                Meta::import();
        }

        
        protected static function insertComment() {

                $data = \apply_filters( "Wpie/Import/Comment/Import/Before", static::prepareComment(), Settings::getContentType() );

                $id = ( DataCenter::isNewItem() ? static::insert( $data ) : static::update( $data ));

                if ( false === $id ) {
                        return false;
                }

                if ( \is_wp_error( $id ) ) {

                        Logger::log( "<strong>" . __( "ERROR", 'wp-import-export' ) . "</strong> : " . $id->get_error_message() );

                        return false;
                }

                if ( \absint( $id ) === 0 ) {

                        Logger::log( "<strong>" . __( "ERROR", 'wp-import-export' ) . "</strong> : " . __( "something wrong, ID = 0 was generated.", 'wp-import-export' ) );

                        return false;
                }

                static::setItem( $id );

                return true;
        }

        
        protected static function insert( $data = [] ) {

                if ( isset( $data[ 'comment_ID' ] ) ) {
                        unset( $data[ 'comment_ID' ] );
                }

                if ( !Helper::isNonEmptyArray( $data ) ) {
                        Logger::log( "<strong>" . __( "ERROR", 'wp-import-export' ) . "</strong> : " . __( "Cannot create a comment with an empty login name.", 'wp-import-export' ) );
                        return false;
                }

                if ( !isset( $data[ 'comment_post_ID' ] ) || \absint( $data[ 'comment_post_ID' ] ) < 1 ) {
                        Logger::log( "<strong>" . __( "ERROR", 'wp-import-export' ) . "</strong> : " . __( "The post is not found", 'wp-import-export' ) );
                        return false;
                }
                if ( !isset( $data[ 'comment_content' ] ) ) {
                        Logger::log( "<strong>" . __( "ERROR", 'wp-import-export' ) . "</strong> : " . __( "Cannot create a comment with an empty content", 'wp-import-export' ) );
                        return false;
                }

                global $wp_version;

                $data = static::filterNewComment( $data );

                return version_compare( $wp_version, '5.5', '<' ) ? \wp_insert_comment( $data ) : \wp_insert_comment( $data, true );
        }

        
        protected static function update( $data = [] ) {

                if ( !Helper::isNonEmptyArray( $data ) ) {
                        return DataCenter::getId();
                }

                global $wp_version;

                $data[ 'comment_ID' ] = DataCenter::getId();

                $result = version_compare( $wp_version, '5.5', '<' ) ? \wp_update_comment( $data ) : \wp_update_comment( $data, true );

                if ( \is_wp_error( $result ) ) {

                        Logger::log( "<strong>" . __( "ERROR", 'wp-import-export' ) . "</strong> : " . $result->get_error_message() );
                }

                return DataCenter::getId();
        }

        
        protected static function filterNewComment( $data = [] ) {

                if ( !isset( $data[ 'comment_type' ] ) || !Helper::isNonEmptyStr( $data[ 'comment_type' ] ) ) {
                        $data[ 'comment_type' ] = 'comment';
                }

                return \wp_filter_comment( $data );
        }

        
        public static function searchDuplicates() {

                $searchMethod = DataCenter::get( "search/method" );

                $id = 0;

                switch ( $searchMethod ) {

                        case "content":
                                $content = DataCenter::get( "search/content/data" );
                                $date    = DataCenter::get( "search/content/date" );

                                $ids = AutoSearch::tryDateAndContent( $content, $date );

                                $id = is_array( $ids ) ? array_shift( $ids ) : 0;

                                break;
                        case "id":
                                $field = DataCenter::get( "search/id" );

                                $id = Helper::isNonEmptyStr( $field ) ? Search::getCommentById( 'id', $field ) : 0;

                                break;
                        case "meta":
                                $metaKey   = DataCenter::get( "search/meta/key" );
                                $metaValue = DataCenter::get( "search/meta/value" );

                                if ( Helper::isNonEmptyStr( $metaKey ) && Helper::isNonEmptyStr( $metaValue ) ) {
                                        $id = Search::getCommentIdByMeta( $metaKey, $metaValue );
                                }
                                break;

                        default:
                                $id = AutoSearch::get();
                                break;
                }

                return $id;
        }
}
