<?php



namespace WpieApp\Modules\Import\Controller\Items\User\Engines;

use WpieApp\Core\Utils\DB;
use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\Controller\Settings;
use WpieApp\Modules\Import\Controller\Items\Base\Logger;
use WpieApp\Modules\Import\Controller\Items\User\DataCenter;
use WpieApp\Modules\Import\Controller\Items\User\Engine;

defined( 'WPIE__FILE__' ) || exit;


class Standard {

        
        private static $siteRoles;

        
        public static function get() {

                $data = [];

                if ( DataCenter::canUpdate( "standard/login" ) ) {
                        $data[ "user_login" ] = DataCenter::get( "standard/login/data" );
                }

                if ( DataCenter::canUpdate( "standard/email" ) ) {
                        $data[ "user_email" ] = DataCenter::get( "standard/email/data" );
                }
                if ( DataCenter::canUpdate( "standard/password" ) ) {
                        $data[ "user_pass" ] = DataCenter::get( "standard/password/data" );
                }
                if ( DataCenter::canUpdate( "standard/role" ) ) {

                        $roles = self::getRoles();

                        $role = (is_array( $roles ) && count( $roles ) >= 1) ? array_shift( $roles ) : '';

                        if ( Helper::isNonEmptyStr( $role ) ) {
                                $data[ "role" ] = $role;
                        }
                }

                if ( DataCenter::canUpdate( "standard/firstname" ) ) {
                        $data[ "first_name" ] = DataCenter::get( "standard/firstname/data" );
                }

                if ( DataCenter::canUpdate( "standard/lastname" ) ) {
                        $data[ "last_name" ] = DataCenter::get( "standard/lastname/data" );
                }

                return $data;
        }

        
        private static function getSiteRoles() {

                if ( is_null( self::$siteRoles ) ) {

                        $wp_roles = \wp_roles();

                        self::$siteRoles = $wp_roles->get_names();

                        unset( $wp_roles );
                }

                return self::$siteRoles;
        }

        
        public static function update() {

                $isPasswordUpdated = self::updatePassword();

                $isRoleUpdated = self::updateRole();

                $isCapUpdated = self::updateCapabilities();

                if ( $isPasswordUpdated || $isRoleUpdated || $isCapUpdated ) {
                        \clean_user_cache( DataCenter::getId() );
                }
        }

        
        private static function updateRole() {

                if ( !DataCenter::canUpdate( "standard/role" ) ) {
                        return false;
                }

                if ( Engine::getCurrentUserId() === DataCenter::getId() ) {
                        return false;
                }

                $roles = self::getRoles();

                if ( !is_array( $roles ) || count( $roles ) <= 1 ) {
                        return false;
                }

                array_shift( $roles );

                foreach ( $roles as $role ) {

                        DataCenter::getItem()->add_role( $role );
                }

                return true;
        }

        
        private static function getRoles() {

                $roles = DataCenter::get( "standard/role/data" );

                $separator = DataCenter::get( "standard/role/separator" );

                $userRoles = Helper::isNonEmptyStr( $roles ) ? Helper::strToArr( $roles, $separator ) : [];

                if ( count( $userRoles ) < 1 ) {
                        return false;
                }

                $siteRoles = self::getSiteRoles();

                $result = [];

                foreach ( $userRoles as $role ) {

                        if ( !Helper::isNonEmptyStr( $role ) ) {
                                continue;
                        }

                        $role = Helper::sanitizeKey( $role );

                        if ( isset( $siteRoles[ $role ] ) ) {
                                $detectedRole = $role;
                        } elseif ( in_array( $role, $siteRoles ) ) {
                                $detectedRole = array_search( $detectedRole, $siteRoles );
                        } else {
                                $detectedRole = Helper::autoFixStr( $role, array_keys( $siteRoles ), false );
                        }

                        if ( !Helper::isNonEmptyStr( $detectedRole ) ) {
                                continue;
                        }

                        $result[] = $detectedRole;
                }

                return $result;
        }

        
        private static function updateCapabilities() {

                if ( !DataCenter::canUpdate( "standard/capability" ) ) {
                        return false;
                }

                $caps = DataCenter::get( "standard/capability/data" );

                if ( !Helper::isNonEmptyStr( $caps ) ) {
                        return false;
                }

                $data = Helper::jsonDecode( $caps, true );

                if ( \is_wp_error( $data ) ) {
                        Logger::log( __( "Meta Capabilities Error", 'wp-import-export' ) . " : " . $data->get_error_message() );
                        return false;
                }

                foreach ( $data as $cap => $access ) {

                        if ( !Helper::isNonEmptyStr( $cap ) ) {
                                continue;
                        }

                        $access = (Helper::detectBoolVal( $access ) === false ? false : true);

                        DataCenter::getItem()->add_cap( $cap, $access );
                }

                return true;
        }

        
        private static function updatePassword() {

                if ( !DataCenter::canUpdate( "standard/password" ) ) {
                        return false;
                }
                if ( 1 !== \absint( DataCenter::get( "standard/password/hashed" ) ) ) {
                        return false;
                }

                if ( Engine::getCurrentUserId() === DataCenter::getId() ) {
                        return false;
                }

                $password = DataCenter::get( "standard/password/data" );

                if ( !Helper::isNonEmptyStr( $password ) ) {
                        return false;
                }

                DB::wpdb()->update( DB::wpdb()->users, [ "user_pass" => $password ], [ 'ID' => DataCenter::getId() ] );

                return true;
        }

}
