<?php



namespace WpieApp\Modules\Import\Helpers;

use Exception;
use WP_Error;
use WpieApp\Core\Admin\AutoLoader;
use PhpOffice\PhpSpreadsheet\IOFactory;
use WpieApp\Core\Resource\Resource;
use WpieApp\Core\Utils\OpenSpout;

defined( 'WPIE__FILE__' ) || exit;


trait Excel {

        
        private static $hasMultipleSheets = [ 'xls', 'xlsx', 'ods' ];

        
        public static function supportMultipleSheets( $file = "" ) {

                if ( !Helper::isNonEmptyStr( $file ) ) {
                        return false;
                }

                $ext = Helper::getFileExt( $file );

                if ( in_array( $ext, self::$hasMultipleSheets ) ) {

                        return true;
                }

                return false;
        }

        
        public static function getSheets( $file = "" ) {

                if ( !self::supportMultipleSheets( $file ) ) {
                        return false;
                }

                AutoLoader::loadSpreadsheet();

                try {
                        $reader = IOFactory::createReaderForFile( $file );
                } catch ( Exception $e ) {

                        return self::getSheetsByOpenSpout( $file );
                }

                $reader->setReadDataOnly( true );

                $worksheetNames = $reader->listWorksheetNames( $file );

                unset( $reader );

                return $worksheetNames;
        }

        
        private static function getSheetsByOpenSpout( $file = "" ) {

                try {
                        $reader = OpenSpout::getReader( $file );
                } catch ( Exception $e ) {

                        return new WP_Error( 'wpieError', $e->getMessage() );
                }

                $sheets = $reader->getSheetIterator();

                $worksheetNames = [];
                // Iterate over sheets and print their details
                foreach ( $sheets as $sheet ) {

                        $worksheetNames[] = $sheet->getName();
                }

                $reader->close();

                unset( $reader, $sheets );

                return $worksheetNames;
        }
}
