<?php



namespace WpieApp\Providers;

use WpieApp\Core\Helpers\Helper;

defined( 'WPIE__FILE__' ) || exit;


class Menu {

        
        Private static $menus = [];

        
        const PARENT_ID = 'wpie-export';

        
        private static $parentId = '';

        
        public static function init() {

                self::setAssets();

                \add_action( 'admin_menu', [ __CLASS__, 'register' ] );
                \add_action( 'add_menu_classes', [ __CLASS__, 'addMenuClass' ] );
        }

        
        public static function getCapabilities() {

                $caps = [];

                foreach ( self::$menus as $menu ) {

                        $title = isset( $menu[ 'name' ] ) ? $menu[ 'name' ] : "";

                        $capability = isset( $menu[ 'slug' ] ) && !empty( $menu[ 'slug' ] ) ? Helper::getUserCapByModule( $menu[ 'slug' ] ) : '';

                        $caps[ $capability ] = $title;
                }

                return $caps;
        }

        
        public static function register() {

                self::preprocessMenu();

                \add_menu_page( \esc_html__( 'WP Imp Exp', 'wp-import-export' ), \esc_html__( 'WP Imp Exp', 'wp-import-export' ), self::$parentId, self::$parentId, [ __CLASS__, 'view' ], "", 90.101010101 );

                Helper::addCurrentUserPermission( self::$parentId );

                if ( !Helper::isNonEmptyArray( self::$menus ) ) {
                        return;
                }

                foreach ( self::$menus as $menu ) {

                        $position   = isset( $menu[ 'position' ] ) ? $menu[ 'position' ] : 50;
                        $title      = isset( $menu[ 'name' ] ) ? $menu[ 'name' ] : "";
                        $menuTitle  = isset( $menu[ 'name' ] ) && !empty( $menu[ 'name' ] ) ? $menu[ 'name' ] : $title;
                        $capability = $slug       = isset( $menu[ 'slug' ] ) && !empty( $menu[ 'slug' ] ) ? Helper::getUserCapByModule( $menu[ 'slug' ] ) : '';

                        Helper::addCurrentUserPermission( $capability );

                        \add_submenu_page( self::$parentId, $title, $menuTitle, $capability, sanitize_title( $slug ), [ __CLASS__, 'view' ], $position );
                }
        }

        
        public static function preprocessMenu() {

                if ( Helper::isNonEmptyStr( self::$parentId ) ) {
                        return;
                }

                self::$menus = Helper::sortBy( self::$menus, "position" );

                foreach ( self::$menus as $menu ) {
                        self::$parentId = isset( $menu[ 'slug' ] ) && !empty( $menu[ 'slug' ] ) ? Helper::getUserCapByModule( $menu[ 'slug' ] ) : '';
                        break;
                }
        }

        
        public static function add( $name = null, $slug = "", $assets = [], $position = 50 ) {

                if ( Helper::isEmptyStr( $name ) || Helper::isEmptyStr( $slug ) ) {
                        return;
                }

                if ( isset( self::$menus[ $slug ] ) ) {
                        return;
                }

                self::$menus[ $slug ] = [
                        "name"     => $name,
                        "assets"   => $assets,
                        "position" => $position,
                        "slug"     => $slug,
                ];
        }

        
        public static function view() {

                $activeModule = Helper::getActiveModule();

                if ( Helper::isEmptyStr( $activeModule ) ) {
                        return;
                }


                $class = "WpieApp\\Modules\\" . $activeModule . "\\View\\Page";

                if ( !class_exists( $class ) ) {
                        print \esc_html( $activeModule . ' - view not exists!' );
                        exit;
                }

                $class::render();
        }

        
        private static function setAssets() {

                $activeModule = Helper::getActiveModule();

                if ( Helper::isEmptyStr( $activeModule ) || !isset( self::$menus[ $activeModule ] ) ) {
                        Assets::enqueueDefault();
                        return;
                }

                $assets = isset( self::$menus[ $activeModule ][ "assets" ] ) ? self::$menus[ $activeModule ][ "assets" ] : [];

                Assets::setData( $assets );
        }

        
        public static function addMenuClass( $menu ) {

                foreach ( $menu as $key => $item ) {
                        if ( $item[ 2 ] === self::$parentId ) {
                                $menu[ $key ][ 4 ] .= ' wpie-menu-top'; // Append the custom class to the menu item
                                break;
                        }
                }

                return $menu;
        }
}
